from _typeshed import Incomplete

def SeriesFactory(
    values,
    xvalues: Incomplete | None = None,
    zvalues: Incomplete | None = None,
    title: object = None,
    title_from_data: bool = False,
): ...
