from _typeshed import Incomplete

def format_smart_table(data, column_names): ...
def format_pretty_table(data, column_names: Incomplete | None = None, horizontal_bar: str = "-", vertical_bar: str = "|"): ...
def format_robust_table(data, column_names): ...
def format_rst_table(data, column_names: Incomplete | None = None): ...
