from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def is_tournament(G): ...
@_dispatch
def hamiltonian_path(G): ...
@_dispatch
def random_tournament(n, seed: Incomplete | None = None): ...
@_dispatch
def score_sequence(G): ...
@_dispatch
def is_reachable(G, s, t): ...
@_dispatch
def is_strongly_connected(G): ...
