from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class DBRPsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_dbrpid(self, dbrp_id, **kwargs): ...
    def delete_dbrpid_with_http_info(self, dbrp_id, **kwargs): ...
    async def delete_dbrpid_async(self, dbrp_id, **kwargs): ...
    def get_dbr_ps(self, **kwargs): ...
    def get_dbr_ps_with_http_info(self, **kwargs): ...
    async def get_dbr_ps_async(self, **kwargs): ...
    def get_dbr_ps_id(self, dbrp_id, **kwargs): ...
    def get_dbr_ps_id_with_http_info(self, dbrp_id, **kwargs): ...
    async def get_dbr_ps_id_async(self, dbrp_id, **kwargs): ...
    def patch_dbrpid(self, dbrp_id, dbrp_update, **kwargs): ...
    def patch_dbrpid_with_http_info(self, dbrp_id, dbrp_update, **kwargs): ...
    async def patch_dbrpid_async(self, dbrp_id, dbrp_update, **kwargs): ...
    def post_dbrp(self, dbrp_create, **kwargs): ...
    def post_dbrp_with_http_info(self, dbrp_create, **kwargs): ...
    async def post_dbrp_async(self, dbrp_create, **kwargs): ...
