from _typeshed import Incomplete

class MerchantAccountGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def create(self, params: Incomplete | None = None): ...
    def update(self, merchant_account_id, params: Incomplete | None = None): ...
    def find(self, merchant_account_id): ...
    def create_for_currency(self, params: Incomplete | None = None): ...
    def all(self): ...
