from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

DEFAULT_MOUNT_POINT: str

class Github(VaultApiBase):
    def configure(
        self,
        organization,
        base_url: Incomplete | None = None,
        ttl: Incomplete | None = None,
        max_ttl: Incomplete | None = None,
        mount_point="github",
    ): ...
    def read_configuration(self, mount_point="github"): ...
    def map_team(self, team_name, policies: Incomplete | None = None, mount_point="github"): ...
    def read_team_mapping(self, team_name, mount_point="github"): ...
    def map_user(self, user_name, policies: Incomplete | None = None, mount_point="github"): ...
    def read_user_mapping(self, user_name, mount_point="github"): ...
    def login(self, token, use_token: bool = True, mount_point="github"): ...
