from matplotlib.colors import ListedColormap

# generated
rocket: ListedColormap
mako: ListedColormap
icefire: ListedColormap
vlag: ListedColormap
flare: ListedColormap
crest: ListedColormap
rocket_r: ListedColormap
mako_r: ListedColormap
icefire_r: ListedColormap
vlag_r: ListedColormap
flare_r: ListedColormap
crest_r: ListedColormap
