from .__version__ import (
    __author__ as __author__,
    __author_email__ as __author_email__,
    __copyright__ as __copyright__,
    __description__ as __description__,
    __license__ as __license__,
    __title__ as __title__,
    __url__ as __url__,
    __version__ as __version__,
)
from .slugify import *
from .special import *
