from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def LCF_graph(n, shift_list, repeats, create_using: Incomplete | None = None): ...
@_dispatch
def bull_graph(create_using: Incomplete | None = None): ...
@_dispatch
def chvatal_graph(create_using: Incomplete | None = None): ...
@_dispatch
def cubical_graph(create_using: Incomplete | None = None): ...
@_dispatch
def desargues_graph(create_using: Incomplete | None = None): ...
@_dispatch
def diamond_graph(create_using: Incomplete | None = None): ...
@_dispatch
def dodecahedral_graph(create_using: Incomplete | None = None): ...
@_dispatch
def frucht_graph(create_using: Incomplete | None = None): ...
@_dispatch
def heawood_graph(create_using: Incomplete | None = None): ...
@_dispatch
def hoffman_singleton_graph(): ...
@_dispatch
def house_graph(create_using: Incomplete | None = None): ...
@_dispatch
def house_x_graph(create_using: Incomplete | None = None): ...
@_dispatch
def icosahedral_graph(create_using: Incomplete | None = None): ...
@_dispatch
def krackhardt_kite_graph(create_using: Incomplete | None = None): ...
@_dispatch
def moebius_kantor_graph(create_using: Incomplete | None = None): ...
@_dispatch
def octahedral_graph(create_using: Incomplete | None = None): ...
@_dispatch
def pappus_graph(): ...
@_dispatch
def petersen_graph(create_using: Incomplete | None = None): ...
@_dispatch
def sedgewick_maze_graph(create_using: Incomplete | None = None): ...
@_dispatch
def tetrahedral_graph(create_using: Incomplete | None = None): ...
@_dispatch
def truncated_cube_graph(create_using: Incomplete | None = None): ...
@_dispatch
def truncated_tetrahedron_graph(create_using: Incomplete | None = None): ...
@_dispatch
def tutte_graph(create_using: Incomplete | None = None): ...
