from _typeshed import Incomplete

class QueryVariablePropertiesValues:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, query: Incomplete | None = None, language: Incomplete | None = None) -> None: ...
    @property
    def query(self): ...
    @query.setter
    def query(self, query) -> None: ...
    @property
    def language(self): ...
    @language.setter
    def language(self, language) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
