from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def projected_graph(B, nodes, multigraph: bool = False): ...
@_dispatch
def weighted_projected_graph(B, nodes, ratio: bool = False): ...
@_dispatch
def collaboration_weighted_projected_graph(B, nodes): ...
@_dispatch
def overlap_weighted_projected_graph(B, nodes, jaccard: bool = True): ...
@_dispatch
def generic_weighted_projected_graph(B, nodes, weight_function: Incomplete | None = None): ...
