from _typeshed import Incomplete

class OAuthGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def create_token_from_code(self, params): ...
    def create_token_from_refresh_token(self, params): ...
    def revoke_access_token(self, access_token): ...
    def connect_url(self, raw_params): ...
