from _typeshed import ReadableBuffer

class Error(Exception): ...

def ZSTD_compress(data: ReadableBuffer, level: int = ..., threads: int = ..., /) -> bytes: ...
def ZSTD_external() -> int: ...
def ZSTD_uncompress(data: ReadableBuffer, /) -> bytes: ...
def ZSTD_version() -> str: ...
def ZSTD_version_number() -> int: ...
def ZSTD_threads_count() -> int: ...
def ZSTD_max_threads_count() -> int: ...
def compress(data: ReadableBuffer, level: int = ..., threads: int = ..., /) -> bytes: ...
def decompress(data: ReadableBuffer, /) -> bytes: ...
def dumps(data: ReadableBuffer, level: int = ..., threads: int = ..., /) -> bytes: ...
def loads(data: ReadableBuffer, /) -> bytes: ...
def uncompress(data: ReadableBuffer, /) -> bytes: ...
def version() -> str: ...
