from _typeshed import Incomplete

class SepaDirectDebitAccountGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def find(self, sepa_direct_debit_account_token): ...
    def delete(self, sepa_direct_debit_account_token): ...
