from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def lukes_partitioning(G, max_size, node_weight: Incomplete | None = None, edge_weight: Incomplete | None = None): ...
