from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class Missouri(UnitedStates):
    FIXED_HOLIDAYS: Incomplete
    include_lincoln_birthday: ClassVar[bool]
