from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class MetricsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_metrics(self, **kwargs): ...
    def get_metrics_with_http_info(self, **kwargs): ...
    async def get_metrics_async(self, **kwargs): ...
