from _typeshed import Incomplete

class ApplePayGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def register_domain(self, domain): ...
    def unregister_domain(self, domain): ...
    def registered_domains(self): ...
