from _typeshed import Incomplete

from influxdb_client.domain.threshold_base import ThresholdBase

class RangeThreshold(ThresholdBase):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: str = "range",
        min: Incomplete | None = None,
        max: Incomplete | None = None,
        within: Incomplete | None = None,
        level: Incomplete | None = None,
        all_values: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def min(self): ...
    @min.setter
    def min(self, min) -> None: ...
    @property
    def max(self): ...
    @max.setter
    def max(self, max) -> None: ...
    @property
    def within(self): ...
    @within.setter
    def within(self, within) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
