CR_ERROR_FIRST: int
CR_UNKNOWN_ERROR: int
CR_SOCKET_CREATE_ERROR: int
CR_CONNECTION_ERROR: int
CR_CONN_HOST_ERROR: int
CR_IPSOCK_ERROR: int
CR_UNKNOWN_HOST: int
CR_SERVER_GONE_ERROR: int
CR_VERSION_ERROR: int
CR_OUT_OF_MEMORY: int
CR_WRONG_HOST_INFO: int
CR_LOCALHOST_CONNECTION: int
CR_TCP_CONNECTION: int
CR_SERVER_HANDSHAKE_ERR: int
CR_SERVER_LOST: int
CR_COMMANDS_OUT_OF_SYNC: int
CR_NAMEDPIPE_CONNECTION: int
CR_NAMEDPIPEWAIT_ERROR: int
CR_NAMEDPIPEOPEN_ERROR: int
CR_NAMEDPIPESETSTATE_ERROR: int
CR_CANT_READ_CHARSET: int
CR_NET_PACKET_TOO_LARGE: int
CR_EMBEDDED_CONNECTION: int
CR_PROBE_SLAVE_STATUS: int
CR_PROBE_SLAVE_HOSTS: int
CR_PROBE_SLAVE_CONNECT: int
CR_PROBE_MASTER_CONNECT: int
CR_SSL_CONNECTION_ERROR: int
CR_MALFORMED_PACKET: int
CR_WRONG_LICENSE: int
CR_NULL_POINTER: int
CR_NO_PREPARE_STMT: int
CR_PARAMS_NOT_BOUND: int
CR_DATA_TRUNCATED: int
CR_NO_PARAMETERS_EXISTS: int
CR_INVALID_PARAMETER_NO: int
CR_INVALID_BUFFER_USE: int
CR_UNSUPPORTED_PARAM_TYPE: int
CR_SHARED_MEMORY_CONNECTION: int
CR_SHARED_MEMORY_CONNECT_REQUEST_ERROR: int
CR_SHARED_MEMORY_CONNECT_ANSWER_ERROR: int
CR_SHARED_MEMORY_CONNECT_FILE_MAP_ERROR: int
CR_SHARED_MEMORY_CONNECT_MAP_ERROR: int
CR_SHARED_MEMORY_FILE_MAP_ERROR: int
CR_SHARED_MEMORY_MAP_ERROR: int
CR_SHARED_MEMORY_EVENT_ERROR: int
CR_SHARED_MEMORY_CONNECT_ABANDONED_ERROR: int
CR_SHARED_MEMORY_CONNECT_SET_ERROR: int
CR_CONN_UNKNOW_PROTOCOL: int
CR_INVALID_CONN_HANDLE: int
CR_SECURE_AUTH: int
CR_FETCH_CANCELED: int
CR_NO_DATA: int
CR_NO_STMT_METADATA: int
CR_NO_RESULT_SET: int
CR_NOT_IMPLEMENTED: int
CR_SERVER_LOST_EXTENDED: int
CR_STMT_CLOSED: int
CR_NEW_STMT_METADATA: int
CR_ALREADY_CONNECTED: int
CR_AUTH_PLUGIN_CANNOT_LOAD: int
CR_DUPLICATE_CONNECTION_ATTR: int
CR_AUTH_PLUGIN_ERR: int
CR_ERROR_LAST: int
