from .noop_traceid import NoOpTraceId as NoOpTraceId
from .segment import Segment as Segment
from .subsegment import Subsegment as Subsegment
from .traceid import TraceId as TraceId

class DummySegment(Segment):
    sampled: bool
    def __init__(self, name: str = "dummy") -> None: ...
    def set_aws(self, aws_meta) -> None: ...
    def put_http_meta(self, key, value) -> None: ...
    def put_annotation(self, key, value) -> None: ...
    def put_metadata(self, key, value, namespace: str = "default") -> None: ...
    def set_user(self, user) -> None: ...
    def set_service(self, service_info) -> None: ...
    def apply_status_code(self, status_code) -> None: ...
    def add_exception(self, exception, stack, remote: bool = False) -> None: ...
    def serialize(self) -> None: ...

class DummySubsegment(Subsegment):
    sampled: bool
    def __init__(self, segment, name: str = "dummy") -> None: ...
    def set_aws(self, aws_meta) -> None: ...
    def put_http_meta(self, key, value) -> None: ...
    def put_annotation(self, key, value) -> None: ...
    def put_metadata(self, key, value, namespace: str = "default") -> None: ...
    def set_sql(self, sql) -> None: ...
    def apply_status_code(self, status_code) -> None: ...
    def add_exception(self, exception, stack, remote: bool = False) -> None: ...
    def serialize(self) -> None: ...
