from _typeshed import Incomplete

HTTP_CONTINUE: int
HTTP_SWITCHING_PROTOCOLS: int
HTTP_PROCESSING: int
HTTP_OK: int
HTTP_CREATED: int
HTTP_ACCEPTED: int
HTTP_NON_AUTHORITATIVE: int
HTTP_NO_CONTENT: int
HTTP_RESET_CONTENT: int
HTTP_PARTIAL_CONTENT: int
HTTP_MULTI_STATUS: int
HTTP_MULTIPLE_CHOICES: int
HTTP_MOVED_PERMANENTLY: int
HTTP_MOVED_TEMPORARILY: int
HTTP_SEE_OTHER: int
HTTP_NOT_MODIFIED: int
HTTP_USE_PROXY: int
HTTP_TEMPORARY_REDIRECT: int
HTTP_BAD_REQUEST: int
HTTP_UNAUTHORIZED: int
HTTP_PAYMENT_REQUIRED: int
HTTP_FORBIDDEN: int
HTTP_NOT_FOUND: int
HTTP_METHOD_NOT_ALLOWED: int
HTTP_NOT_ACCEPTABLE: int
HTTP_PROXY_AUTHENTICATION_REQUIRED: int
HTTP_REQUEST_TIME_OUT: int
HTTP_CONFLICT: int
HTTP_GONE: int
HTTP_LENGTH_REQUIRED: int
HTTP_PRECONDITION_FAILED: int
HTTP_REQUEST_ENTITY_TOO_LARGE: int
HTTP_REQUEST_URI_TOO_LARGE: int
HTTP_UNSUPPORTED_MEDIA_TYPE: int
HTTP_RANGE_NOT_SATISFIABLE: int
HTTP_EXPECTATION_FAILED: int
HTTP_UNPROCESSABLE_ENTITY: int
HTTP_INTERNAL_SERVER_ERROR: int
HTTP_NOT_IMPLEMENTED: int
HTTP_BAD_GATEWAY: int
HTTP_SERVICE_UNAVAILABLE: int
HTTP_GATEWAY_TIME_OUT: int
HTTP_VERSION_NOT_SUPPORTED: int
HTTP_VARIANT_ALSO_VARIES: int
HSE_STATUS_SUCCESS: int
HSE_STATUS_SUCCESS_AND_KEEP_CONN: int
HSE_STATUS_PENDING: int
HSE_STATUS_ERROR: int
SF_NOTIFY_SECURE_PORT: int
SF_NOTIFY_NONSECURE_PORT: int
SF_NOTIFY_READ_RAW_DATA: int
SF_NOTIFY_PREPROC_HEADERS: int
SF_NOTIFY_AUTHENTICATION: int
SF_NOTIFY_URL_MAP: int
SF_NOTIFY_ACCESS_DENIED: int
SF_NOTIFY_SEND_RESPONSE: int
SF_NOTIFY_SEND_RAW_DATA: int
SF_NOTIFY_LOG: int
SF_NOTIFY_END_OF_REQUEST: int
SF_NOTIFY_END_OF_NET_SESSION: int
SF_NOTIFY_ORDER_HIGH: int
SF_NOTIFY_ORDER_MEDIUM: int
SF_NOTIFY_ORDER_LOW: int
SF_NOTIFY_ORDER_DEFAULT: int
SF_NOTIFY_ORDER_MASK: Incomplete
SF_STATUS_REQ_FINISHED: int
SF_STATUS_REQ_FINISHED_KEEP_CONN: Incomplete
SF_STATUS_REQ_NEXT_NOTIFICATION: Incomplete
SF_STATUS_REQ_HANDLED_NOTIFICATION: Incomplete
SF_STATUS_REQ_ERROR: Incomplete
SF_STATUS_REQ_READ_NEXT: Incomplete
HSE_IO_SYNC: int
HSE_IO_ASYNC: int
HSE_IO_DISCONNECT_AFTER_SEND: int
HSE_IO_SEND_HEADERS: int
HSE_IO_NODELAY: int
HSE_IO_FINAL_SEND: int
HSE_IO_CACHE_RESPONSE: int
HSE_EXEC_URL_NO_HEADERS: int
HSE_EXEC_URL_IGNORE_CURRENT_INTERCEPTOR: int
HSE_EXEC_URL_IGNORE_VALIDATION_AND_RANGE: int
HSE_EXEC_URL_DISABLE_CUSTOM_ERROR: int
HSE_EXEC_URL_SSI_CMD: int
HSE_EXEC_URL_HTTP_CACHE_ELIGIBLE: int
