from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class WriteService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def post_write(self, org, bucket, body, **kwargs): ...
    def post_write_with_http_info(self, org, bucket, body, **kwargs): ...
    async def post_write_async(self, org, bucket, body, **kwargs): ...
