from _typeshed import Incomplete

class WebhookTestingGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def sample_notification(self, kind, id, source_merchant_id: Incomplete | None = None): ...
