from collections.abc import Iterable, Iterator, Sequence
from re import Pattern
from typing import Any

from pyflakes.reporter import Reporter

__all__ = ["check", "checkPath", "checkRecursive", "iterSourceCode", "main"]

PYTHON_SHEBANG_REGEX: Pattern[bytes]

def check(codeString: str, filename: str, reporter: Reporter | None = None) -> int: ...
def checkPath(filename, reporter: Reporter | None = None) -> int: ...
def isPythonFile(filename) -> bool: ...
def iterSourceCode(paths: Iterable[Any]) -> Iterator[Any]: ...
def checkRecursive(paths: Iterable[Any], reporter: Reporter) -> int: ...
def main(prog: str | None = None, args: Sequence[Any] | None = None) -> None: ...
