from _typeshed import Incomplete

from influxdb_client.domain.scraper_target_request import ScraperTargetRequest

class ScraperTargetResponse(ScraperTargetRequest):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        id: Incomplete | None = None,
        org: Incomplete | None = None,
        bucket: Incomplete | None = None,
        links: Incomplete | None = None,
        name: Incomplete | None = None,
        type: Incomplete | None = None,
        url: Incomplete | None = None,
        org_id: Incomplete | None = None,
        bucket_id: Incomplete | None = None,
        allow_insecure: bool = False,
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def org(self): ...
    @org.setter
    def org(self, org) -> None: ...
    @property
    def bucket(self): ...
    @bucket.setter
    def bucket(self, bucket) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
