from networkx.utils.backends import _dispatch

@_dispatch
def is_graphical(sequence, method: str = "eg"): ...
@_dispatch
def is_valid_degree_sequence_havel_hakimi(deg_sequence): ...
@_dispatch
def is_valid_degree_sequence_erdos_gallai(deg_sequence): ...
@_dispatch
def is_multigraphical(sequence): ...
@_dispatch
def is_pseudographical(sequence): ...
@_dispatch
def is_digraphical(in_sequence, out_sequence): ...
