from typing import ClassVar

from .core import UnitedStates

class Arkansas(UnitedStates):
    include_christmas_eve: ClassVar[bool]
    presidents_day_label: ClassVar[str]
    include_columbus_day: ClassVar[bool]
