from _typeshed import Incomplete

from stripe import api_requestor as api_requestor

def nested_resource_class_methods(
    resource, path: Incomplete | None = None, operations: Incomplete | None = None, resource_plural: Incomplete | None = None
): ...
