from datetime import tzinfo
from typing import Any

class StaticTzInfo(tzinfo):
    def __init__(self, name, offset) -> None: ...
    def tzname(self, dt): ...
    def utcoffset(self, dt): ...
    def dst(self, dt): ...
    def localize(self, dt, is_dst: bool = False): ...
    def __getinitargs__(self): ...

def pop_tz_offset_from_string(date_string, as_offset: bool = True): ...
def word_is_tz(word): ...
def convert_to_local_tz(datetime_obj, datetime_tz_offset): ...
def build_tz_offsets(search_regex_parts): ...
def get_local_tz_offset(): ...

local_tz_offset: Any
