from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def from_sparse6_bytes(string): ...
def to_sparse6_bytes(G, nodes: Incomplete | None = None, header: bool = True): ...
@_dispatch
def read_sparse6(path): ...
def write_sparse6(G, path, nodes: Incomplete | None = None, header: bool = True) -> None: ...
