from _typeshed import Incomplete

class CreditCardVerificationGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def find(self, verification_id): ...
    def search(self, *query): ...
    def create(self, params): ...
