from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def cut_size(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatch
def volume(G, S, weight: Incomplete | None = None): ...
@_dispatch
def normalized_cut_size(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatch
def conductance(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatch
def edge_expansion(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatch
def mixing_expansion(G, S, T: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatch
def node_expansion(G, S): ...
@_dispatch
def boundary_expansion(G, S): ...
