from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Namespace(SystemBackendMixin):
    def create_namespace(self, path): ...
    def list_namespaces(self): ...
    def delete_namespace(self, path): ...
