import gdb

class FrameIterator:
    frame: gdb.Frame

    def __init__(self, frame_obj: gdb.Frame) -> None: ...
    def __iter__(self) -> FrameIterator: ...
    def next(self) -> gdb.Frame: ...
    def __next__(self) -> gdb.Frame: ...
