from braintree.validation_error_collection import ValidationErrorCollection

class Errors:
    errors: ValidationErrorCollection
    size = errors.deep_size
    def __init__(self, data) -> None: ...
    @property
    def deep_errors(self): ...
    def for_object(self, key): ...
    def __len__(self) -> int: ...
