from typing import Literal

AF_INET: Literal[2]
AF_INET6: Literal[10]

def inet_ntoa(packed_ip: bytes) -> str: ...
def inet_ntop(af: int, packed_ip: bytes) -> str: ...
def inet_pton(af: int, ip_string: str) -> str: ...
