from typing import Final

XK_Hstroke: Final = 0x2A1
XK_Hcircumflex: Final = 0x2A6
XK_Iabovedot: Final = 0x2A9
XK_Gbreve: Final = 0x2AB
XK_Jcircumflex: Final = 0x2AC
XK_hstroke: Final = 0x2B1
XK_hcircumflex: Final = 0x2B6
XK_idotless: Final = 0x2B9
XK_gbreve: Final = 0x2BB
XK_jcircumflex: Final = 0x2BC
XK_Cabovedot: Final = 0x2C5
XK_Ccircumflex: Final = 0x2C6
XK_Gabovedot: Final = 0x2D5
XK_Gcircumflex: Final = 0x2D8
XK_Ubreve: Final = 0x2DD
XK_Scircumflex: Final = 0x2DE
XK_cabovedot: Final = 0x2E5
XK_ccircumflex: Final = 0x2E6
XK_gabovedot: Final = 0x2F5
XK_gcircumflex: Final = 0x2F8
XK_ubreve: Final = 0x2FD
XK_scircumflex: Final = 0x2FE
