from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def harmonic_centrality(
    G, nbunch: Incomplete | None = None, distance: Incomplete | None = None, sources: Incomplete | None = None
): ...
