class JOSEError(Exception): ...
class JWSError(JOSEError): ...
class JWSSignatureError(JWSError): ...
class JWSAlgorithmError(JWSError): ...
class JWTError(JOSEError): ...
class JWTClaimsError(JWTError): ...
class ExpiredSignatureError(JWTError): ...
class JWKError(JOSEError): ...
class JWEError(JOSEError): ...
class JWEParseError(JWEError): ...
class JWEInvalidAuth(JWEError): ...
class JWEAlgorithmUnsupportedError(JWEError): ...
