from _typeshed import Incomplete

from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Raft(SystemBackendMixin):
    def join_raft_cluster(
        self,
        leader_api_addr,
        retry: bool = False,
        leader_ca_cert: Incomplete | None = None,
        leader_client_cert: Incomplete | None = None,
        leader_client_key: Incomplete | None = None,
    ): ...
    def read_raft_config(self): ...
    def remove_raft_node(self, server_id): ...
    def take_raft_snapshot(self): ...
    def restore_raft_snapshot(self, snapshot): ...
    def force_restore_raft_snapshot(self, snapshot): ...
