from networkx.utils.backends import _dispatch

def write_p2g(G, path, encoding: str = "utf-8") -> None: ...
@_dispatch
def read_p2g(path, encoding: str = "utf-8"): ...
@_dispatch
def parse_p2g(lines): ...
