from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def triangles(G, nodes: Incomplete | None = None): ...
@_dispatch
def average_clustering(G, nodes: Incomplete | None = None, weight: Incomplete | None = None, count_zeros: bool = True): ...
@_dispatch
def clustering(G, nodes: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatch
def transitivity(G): ...
@_dispatch
def square_clustering(G, nodes: Incomplete | None = None): ...
@_dispatch
def generalized_degree(G, nodes: Incomplete | None = None): ...
