from _typeshed import Incomplete

from influxdb_client.domain.expression import Expression

class BinaryExpression(Expression):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        operator: Incomplete | None = None,
        left: Incomplete | None = None,
        right: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def operator(self): ...
    @operator.setter
    def operator(self, operator) -> None: ...
    @property
    def left(self): ...
    @left.setter
    def left(self, left) -> None: ...
    @property
    def right(self): ...
    @right.setter
    def right(self, right) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
