from _typeshed import Incomplete

def main() -> None: ...
def run_command(command_line) -> None: ...
def print_formatted_length(value) -> None: ...
def print_formatted_number(value) -> None: ...
def print_formatted_size(value, binary) -> None: ...
def print_formatted_table(delimiter) -> None: ...
def print_formatted_timespan(value) -> None: ...
def print_parsed_length(value) -> None: ...
def print_parsed_size(value) -> None: ...
def demonstrate_ansi_formatting() -> None: ...
def demonstrate_256_colors(i, j, group: Incomplete | None = None) -> None: ...
