from typing import Final

XK_Greek_ALPHAaccent: Final = 0x7A1
XK_Greek_EPSILONaccent: Final = 0x7A2
XK_Greek_ETAaccent: Final = 0x7A3
XK_Greek_IOTAaccent: Final = 0x7A4
XK_Greek_IOTAdiaeresis: Final = 0x7A5
XK_Greek_OMICRONaccent: Final = 0x7A7
XK_Greek_UPSILONaccent: Final = 0x7A8
XK_Greek_UPSILONdieresis: Final = 0x7A9
XK_Greek_OMEGAaccent: Final = 0x7AB
XK_Greek_accentdieresis: Final = 0x7AE
XK_Greek_horizbar: Final = 0x7AF
XK_Greek_alphaaccent: Final = 0x7B1
XK_Greek_epsilonaccent: Final = 0x7B2
XK_Greek_etaaccent: Final = 0x7B3
XK_Greek_iotaaccent: Final = 0x7B4
XK_Greek_iotadieresis: Final = 0x7B5
XK_Greek_iotaaccentdieresis: Final = 0x7B6
XK_Greek_omicronaccent: Final = 0x7B7
XK_Greek_upsilonaccent: Final = 0x7B8
XK_Greek_upsilondieresis: Final = 0x7B9
XK_Greek_upsilonaccentdieresis: Final = 0x7BA
XK_Greek_omegaaccent: Final = 0x7BB
XK_Greek_ALPHA: Final = 0x7C1
XK_Greek_BETA: Final = 0x7C2
XK_Greek_GAMMA: Final = 0x7C3
XK_Greek_DELTA: Final = 0x7C4
XK_Greek_EPSILON: Final = 0x7C5
XK_Greek_ZETA: Final = 0x7C6
XK_Greek_ETA: Final = 0x7C7
XK_Greek_THETA: Final = 0x7C8
XK_Greek_IOTA: Final = 0x7C9
XK_Greek_KAPPA: Final = 0x7CA
XK_Greek_LAMDA: Final = 0x7CB
XK_Greek_LAMBDA: Final = 0x7CB
XK_Greek_MU: Final = 0x7CC
XK_Greek_NU: Final = 0x7CD
XK_Greek_XI: Final = 0x7CE
XK_Greek_OMICRON: Final = 0x7CF
XK_Greek_PI: Final = 0x7D0
XK_Greek_RHO: Final = 0x7D1
XK_Greek_SIGMA: Final = 0x7D2
XK_Greek_TAU: Final = 0x7D4
XK_Greek_UPSILON: Final = 0x7D5
XK_Greek_PHI: Final = 0x7D6
XK_Greek_CHI: Final = 0x7D7
XK_Greek_PSI: Final = 0x7D8
XK_Greek_OMEGA: Final = 0x7D9
XK_Greek_alpha: Final = 0x7E1
XK_Greek_beta: Final = 0x7E2
XK_Greek_gamma: Final = 0x7E3
XK_Greek_delta: Final = 0x7E4
XK_Greek_epsilon: Final = 0x7E5
XK_Greek_zeta: Final = 0x7E6
XK_Greek_eta: Final = 0x7E7
XK_Greek_theta: Final = 0x7E8
XK_Greek_iota: Final = 0x7E9
XK_Greek_kappa: Final = 0x7EA
XK_Greek_lamda: Final = 0x7EB
XK_Greek_lambda: Final = 0x7EB
XK_Greek_mu: Final = 0x7EC
XK_Greek_nu: Final = 0x7ED
XK_Greek_xi: Final = 0x7EE
XK_Greek_omicron: Final = 0x7EF
XK_Greek_pi: Final = 0x7F0
XK_Greek_rho: Final = 0x7F1
XK_Greek_sigma: Final = 0x7F2
XK_Greek_finalsmallsigma: Final = 0x7F3
XK_Greek_tau: Final = 0x7F4
XK_Greek_upsilon: Final = 0x7F5
XK_Greek_phi: Final = 0x7F6
XK_Greek_chi: Final = 0x7F7
XK_Greek_psi: Final = 0x7F8
XK_Greek_omega: Final = 0x7F9
XK_Greek_switch: Final = 0xFF7E
