from _typeshed import Incomplete

LIST_OF_FILE_NAMES: Incomplete

def get_extension(srcfilename, modname, sources=(), **kwds): ...
def compile(tmpdir, ext, compiler_verbose: int = 0, debug: Incomplete | None = None): ...
def maybe_relative_path(path): ...

int_or_long = int

def flatten(x): ...
