from _typeshed import Incomplete

def temporary_chdir(new_dir) -> None: ...
def get_file_directory(): ...
def get_temp_directory(): ...
def get_themes_directory(theme_name: Incomplete | None = None, png: bool = False): ...
def create_directory(directory): ...
