from _typeshed import Incomplete

def add_operation(
    dn, attributes, auto_encode, schema: Incomplete | None = None, validator: Incomplete | None = None, check_names: bool = False
): ...
def add_request_to_dict(request): ...
def add_response_to_dict(response): ...
