from _typeshed import Incomplete

integer_types = int
text_type = str
binary_type = bytes

class Generator:
    dict: dict[Incomplete, Incomplete]
    def __init__(self, dict) -> None: ...
    def generate(self): ...
