from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def is_biconnected(G): ...
@_dispatch
def biconnected_component_edges(G) -> Generator[Incomplete, Incomplete, None]: ...
@_dispatch
def biconnected_components(G) -> Generator[Incomplete, None, None]: ...
@_dispatch
def articulation_points(G) -> Generator[Incomplete, None, None]: ...
