from networkx.utils.backends import _dispatch

@_dispatch
def tensor_product(G, H): ...
@_dispatch
def cartesian_product(G, H): ...
@_dispatch
def lexicographic_product(G, H): ...
@_dispatch
def strong_product(G, H): ...
@_dispatch
def power(G, k): ...
@_dispatch
def rooted_product(G, H, root): ...
@_dispatch
def corona_product(G, H): ...
