from networkx.algorithms.coloring.equitable_coloring import equitable_color as equitable_color
from networkx.algorithms.coloring.greedy_coloring import *

__all__ = ["greedy_color", "equitable_color"]
