from _typeshed import Incomplete

def pid_exists(pid): ...
def wait_pid(
    pid,
    timeout: Incomplete | None = None,
    proc_name: Incomplete | None = None,
    _waitpid=...,
    _timer=...,
    _min=...,
    _sleep=...,
    _pid_exists=...,
): ...
def disk_usage(path): ...
def get_terminal_map(): ...
