from typing import Literal, TypeVar

_T = TypeVar("_T")

ints2octs = bytes

def int2oct(x) -> bytes: ...

null: Literal[b""]

def oct2int(x: _T) -> _T: ...
def octs2ints(x: _T) -> _T: ...
def str2octs(x: str) -> bytes: ...
def octs2str(x: bytes) -> str: ...
def isOctetsType(s: object) -> bool: ...
def isStringType(s: object) -> bool: ...

ensureString = bytes
