def require_string(value, value_name) -> None: ...
def require_callback(callback, callback_name: str = "callback") -> None: ...
def rpc_completion_callback(callback): ...
def zero_or_greater(name, value) -> None: ...
