from typing import Final

PRIMARY: Final = 1
SECONDARY: Final = 2
ARC: Final = 3
ATOM: Final = 4
BITMAP: Final = 5
CARDINAL: Final = 6
COLORMAP: Final = 7
CURSOR: Final = 8
CUT_BUFFER0: Final = 9
CUT_BUFFER1: Final = 10
CUT_BUFFER2: Final = 11
CUT_BUFFER3: Final = 12
CUT_BUFFER4: Final = 13
CUT_BUFFER5: Final = 14
CUT_BUFFER6: Final = 15
CUT_BUFFER7: Final = 16
DRAWABLE: Final = 17
FONT: Final = 18
INTEGER: Final = 19
PIXMAP: Final = 20
POINT: Final = 21
RECTANGLE: Final = 22
RESOURCE_MANAGER: Final = 23
RGB_COLOR_MAP: Final = 24
RGB_BEST_MAP: Final = 25
RGB_BLUE_MAP: Final = 26
RGB_DEFAULT_MAP: Final = 27
RGB_GRAY_MAP: Final = 28
RGB_GREEN_MAP: Final = 29
RGB_RED_MAP: Final = 30
STRING: Final = 31
VISUALID: Final = 32
WINDOW: Final = 33
WM_COMMAND: Final = 34
WM_HINTS: Final = 35
WM_CLIENT_MACHINE: Final = 36
WM_ICON_NAME: Final = 37
WM_ICON_SIZE: Final = 38
WM_NAME: Final = 39
WM_NORMAL_HINTS: Final = 40
WM_SIZE_HINTS: Final = 41
WM_ZOOM_HINTS: Final = 42
MIN_SPACE: Final = 43
NORM_SPACE: Final = 44
MAX_SPACE: Final = 45
END_SPACE: Final = 46
SUPERSCRIPT_X: Final = 47
SUPERSCRIPT_Y: Final = 48
SUBSCRIPT_X: Final = 49
SUBSCRIPT_Y: Final = 50
UNDERLINE_POSITION: Final = 51
UNDERLINE_THICKNESS: Final = 52
STRIKEOUT_ASCENT: Final = 53
STRIKEOUT_DESCENT: Final = 54
ITALIC_ANGLE: Final = 55
X_HEIGHT: Final = 56
QUAD_WIDTH: Final = 57
WEIGHT: Final = 58
POINT_SIZE: Final = 59
RESOLUTION: Final = 60
COPYRIGHT: Final = 61
NOTICE: Final = 62
FONT_NAME: Final = 63
FAMILY_NAME: Final = 64
FULL_NAME: Final = 65
CAP_HEIGHT: Final = 66
WM_CLASS: Final = 67
WM_TRANSIENT_FOR: Final = 68
LAST_PREDEFINED: Final = 68
