from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class NotificationEndpointsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def create_notification_endpoint(self, post_notification_endpoint, **kwargs): ...
    def create_notification_endpoint_with_http_info(self, post_notification_endpoint, **kwargs): ...
    async def create_notification_endpoint_async(self, post_notification_endpoint, **kwargs): ...
    def delete_notification_endpoints_id(self, endpoint_id, **kwargs): ...
    def delete_notification_endpoints_id_with_http_info(self, endpoint_id, **kwargs): ...
    async def delete_notification_endpoints_id_async(self, endpoint_id, **kwargs): ...
    def delete_notification_endpoints_id_labels_id(self, endpoint_id, label_id, **kwargs): ...
    def delete_notification_endpoints_id_labels_id_with_http_info(self, endpoint_id, label_id, **kwargs): ...
    async def delete_notification_endpoints_id_labels_id_async(self, endpoint_id, label_id, **kwargs): ...
    def get_notification_endpoints(self, org_id, **kwargs): ...
    def get_notification_endpoints_with_http_info(self, org_id, **kwargs): ...
    async def get_notification_endpoints_async(self, org_id, **kwargs): ...
    def get_notification_endpoints_id(self, endpoint_id, **kwargs): ...
    def get_notification_endpoints_id_with_http_info(self, endpoint_id, **kwargs): ...
    async def get_notification_endpoints_id_async(self, endpoint_id, **kwargs): ...
    def get_notification_endpoints_id_labels(self, endpoint_id, **kwargs): ...
    def get_notification_endpoints_id_labels_with_http_info(self, endpoint_id, **kwargs): ...
    async def get_notification_endpoints_id_labels_async(self, endpoint_id, **kwargs): ...
    def patch_notification_endpoints_id(self, endpoint_id, notification_endpoint_update, **kwargs): ...
    def patch_notification_endpoints_id_with_http_info(self, endpoint_id, notification_endpoint_update, **kwargs): ...
    async def patch_notification_endpoints_id_async(self, endpoint_id, notification_endpoint_update, **kwargs): ...
    def post_notification_endpoint_id_labels(self, endpoint_id, label_mapping, **kwargs): ...
    def post_notification_endpoint_id_labels_with_http_info(self, endpoint_id, label_mapping, **kwargs): ...
    async def post_notification_endpoint_id_labels_async(self, endpoint_id, label_mapping, **kwargs): ...
    def put_notification_endpoints_id(self, endpoint_id, notification_endpoint, **kwargs): ...
    def put_notification_endpoints_id_with_http_info(self, endpoint_id, notification_endpoint, **kwargs): ...
    async def put_notification_endpoints_id_async(self, endpoint_id, notification_endpoint, **kwargs): ...
