from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class ScraperTargetsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_scrapers_id(self, scraper_target_id, **kwargs): ...
    def delete_scrapers_id_with_http_info(self, scraper_target_id, **kwargs): ...
    async def delete_scrapers_id_async(self, scraper_target_id, **kwargs): ...
    def delete_scrapers_id_labels_id(self, scraper_target_id, label_id, **kwargs): ...
    def delete_scrapers_id_labels_id_with_http_info(self, scraper_target_id, label_id, **kwargs): ...
    async def delete_scrapers_id_labels_id_async(self, scraper_target_id, label_id, **kwargs): ...
    def delete_scrapers_id_members_id(self, user_id, scraper_target_id, **kwargs): ...
    def delete_scrapers_id_members_id_with_http_info(self, user_id, scraper_target_id, **kwargs): ...
    async def delete_scrapers_id_members_id_async(self, user_id, scraper_target_id, **kwargs): ...
    def delete_scrapers_id_owners_id(self, user_id, scraper_target_id, **kwargs): ...
    def delete_scrapers_id_owners_id_with_http_info(self, user_id, scraper_target_id, **kwargs): ...
    async def delete_scrapers_id_owners_id_async(self, user_id, scraper_target_id, **kwargs): ...
    def get_scrapers(self, **kwargs): ...
    def get_scrapers_with_http_info(self, **kwargs): ...
    async def get_scrapers_async(self, **kwargs): ...
    def get_scrapers_id(self, scraper_target_id, **kwargs): ...
    def get_scrapers_id_with_http_info(self, scraper_target_id, **kwargs): ...
    async def get_scrapers_id_async(self, scraper_target_id, **kwargs): ...
    def get_scrapers_id_labels(self, scraper_target_id, **kwargs): ...
    def get_scrapers_id_labels_with_http_info(self, scraper_target_id, **kwargs): ...
    async def get_scrapers_id_labels_async(self, scraper_target_id, **kwargs): ...
    def get_scrapers_id_members(self, scraper_target_id, **kwargs): ...
    def get_scrapers_id_members_with_http_info(self, scraper_target_id, **kwargs): ...
    async def get_scrapers_id_members_async(self, scraper_target_id, **kwargs): ...
    def get_scrapers_id_owners(self, scraper_target_id, **kwargs): ...
    def get_scrapers_id_owners_with_http_info(self, scraper_target_id, **kwargs): ...
    async def get_scrapers_id_owners_async(self, scraper_target_id, **kwargs): ...
    def patch_scrapers_id(self, scraper_target_id, scraper_target_request, **kwargs): ...
    def patch_scrapers_id_with_http_info(self, scraper_target_id, scraper_target_request, **kwargs): ...
    async def patch_scrapers_id_async(self, scraper_target_id, scraper_target_request, **kwargs): ...
    def post_scrapers(self, scraper_target_request, **kwargs): ...
    def post_scrapers_with_http_info(self, scraper_target_request, **kwargs): ...
    async def post_scrapers_async(self, scraper_target_request, **kwargs): ...
    def post_scrapers_id_labels(self, scraper_target_id, label_mapping, **kwargs): ...
    def post_scrapers_id_labels_with_http_info(self, scraper_target_id, label_mapping, **kwargs): ...
    async def post_scrapers_id_labels_async(self, scraper_target_id, label_mapping, **kwargs): ...
    def post_scrapers_id_members(self, scraper_target_id, add_resource_member_request_body, **kwargs): ...
    def post_scrapers_id_members_with_http_info(self, scraper_target_id, add_resource_member_request_body, **kwargs): ...
    async def post_scrapers_id_members_async(self, scraper_target_id, add_resource_member_request_body, **kwargs): ...
    def post_scrapers_id_owners(self, scraper_target_id, add_resource_member_request_body, **kwargs): ...
    def post_scrapers_id_owners_with_http_info(self, scraper_target_id, add_resource_member_request_body, **kwargs): ...
    async def post_scrapers_id_owners_async(self, scraper_target_id, add_resource_member_request_body, **kwargs): ...
