from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class Guam(UnitedStates):
    FIXED_HOLIDAYS: Incomplete
    include_all_souls: ClassVar[bool]
    include_immaculate_conception: ClassVar[bool]
    immaculate_conception_label: ClassVar[str]
