from _typeshed import Incomplete

class TemplateSummaryErrors:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        kind: Incomplete | None = None,
        reason: Incomplete | None = None,
        fields: Incomplete | None = None,
        indexes: Incomplete | None = None,
    ) -> None: ...
    @property
    def kind(self): ...
    @kind.setter
    def kind(self, kind) -> None: ...
    @property
    def reason(self): ...
    @reason.setter
    def reason(self, reason) -> None: ...
    @property
    def fields(self): ...
    @fields.setter
    def fields(self, fields) -> None: ...
    @property
    def indexes(self): ...
    @indexes.setter
    def indexes(self, indexes) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
