from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def color(G): ...
@_dispatch
def is_bipartite(G): ...
@_dispatch
def is_bipartite_node_set(G, nodes): ...
@_dispatch
def sets(G, top_nodes: Incomplete | None = None): ...
@_dispatch
def density(B, nodes): ...
@_dispatch
def degrees(B, nodes, weight: Incomplete | None = None): ...
