from _typeshed import Incomplete

class ClientToken:
    @staticmethod
    def generate(params: Incomplete | None = None, gateway: Incomplete | None = None): ...
    @staticmethod
    def generate_signature(): ...
