from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class QueryService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_query_suggestions(self, **kwargs): ...
    def get_query_suggestions_with_http_info(self, **kwargs): ...
    async def get_query_suggestions_async(self, **kwargs): ...
    def get_query_suggestions_name(self, name, **kwargs): ...
    def get_query_suggestions_name_with_http_info(self, name, **kwargs): ...
    async def get_query_suggestions_name_async(self, name, **kwargs): ...
    def post_query(self, **kwargs): ...
    def post_query_with_http_info(self, **kwargs): ...
    async def post_query_async(self, **kwargs): ...
    def post_query_analyze(self, **kwargs): ...
    def post_query_analyze_with_http_info(self, **kwargs): ...
    async def post_query_analyze_async(self, **kwargs): ...
    def post_query_ast(self, **kwargs): ...
    def post_query_ast_with_http_info(self, **kwargs): ...
    async def post_query_ast_async(self, **kwargs): ...
