from _typeshed import Incomplete

from exifread.tags.exif import EXIF_TAGS as EXIF_TAGS
from exifread.tags.makernote import (
    apple as apple,
    canon as canon,
    casio as casio,
    fujifilm as fujifilm,
    nikon as nikon,
    olympus as olympus,
)

DEFAULT_STOP_TAG: str
FIELD_TYPES: Incomplete
IGNORE_TAGS: Incomplete
