from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def core_number(G): ...
@_dispatch
def k_core(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
@_dispatch
def k_shell(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
@_dispatch
def k_crust(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
@_dispatch
def k_corona(G, k, core_number: Incomplete | None = None): ...
@_dispatch
def k_truss(G, k): ...
@_dispatch
def onion_layers(G): ...
