from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class DistrictOfColumbia(UnitedStates):
    include_inauguration_day: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
