from _typeshed import Incomplete

class CreditCardGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def create(self, params: Incomplete | None = None): ...
    def delete(self, credit_card_token): ...
    def expired(self): ...
    def expiring_between(self, start_date, end_date): ...
    def find(self, credit_card_token): ...
    def forward(self, credit_card_token, receiving_merchant_id) -> None: ...
    def from_nonce(self, nonce): ...
    def update(self, credit_card_token, params: Incomplete | None = None): ...
