from _typeshed import Incomplete

class UsBankAccountGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def find(self, us_bank_account_token): ...
