from _typeshed import Incomplete

class PaymentMethodGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def create(self, params: Incomplete | None = None): ...
    def find(self, payment_method_token): ...
    def update(self, payment_method_token, params): ...
    def delete(self, payment_method_token, options: Incomplete | None = None): ...
    options: dict[str, Incomplete]
    def grant(self, payment_method_token, options: Incomplete | None = None): ...
    def revoke(self, payment_method_token): ...
