from _typeshed import Incomplete
from typing import Any

MAX_ATTEMPTS: int
logger: Any

def prompt_for_confirmation(question, default: Incomplete | None = None, padding: bool = True): ...
def prompt_for_choice(choices, default: Incomplete | None = None, padding: bool = True): ...
def prompt_for_input(question, default: Incomplete | None = None, padding: bool = True, strip: bool = True): ...
def prepare_prompt_text(prompt_text, **options): ...
def prepare_friendly_prompts() -> None: ...
def retry_limit(limit=10) -> None: ...

class TooManyInvalidReplies(Exception): ...
