from _typeshed import Incomplete

from stripe.error import StripeError as StripeError

class OAuthError(StripeError):
    def __init__(
        self,
        code,
        description,
        http_body: Incomplete | None = None,
        http_status: Incomplete | None = None,
        json_body: Incomplete | None = None,
        headers: Incomplete | None = None,
    ) -> None: ...
    def construct_error_object(self): ...

class InvalidClientError(OAuthError): ...
class InvalidGrantError(OAuthError): ...
class InvalidRequestError(OAuthError): ...
class InvalidScopeError(OAuthError): ...
class UnsupportedGrantTypeError(OAuthError): ...
class UnsupportedResponseTypeError(OAuthError): ...
