language: str
windowmanager: str | None
icon_theme: str
icon_size: int
cache_time: int
root_mode: bool

def setWindowManager(wm: str) -> None: ...
def setIconTheme(theme: str) -> None: ...
def setIconSize(size: int) -> None: ...
def setCacheTime(time: int) -> None: ...
def setLocale(lang: str) -> None: ...
def setRootMode(boolean: bool) -> None: ...
