from _typeshed import Incomplete

class TemplateChart:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        x_pos: Incomplete | None = None,
        y_pos: Incomplete | None = None,
        height: Incomplete | None = None,
        width: Incomplete | None = None,
        properties: Incomplete | None = None,
    ) -> None: ...
    @property
    def x_pos(self): ...
    @x_pos.setter
    def x_pos(self, x_pos) -> None: ...
    @property
    def y_pos(self): ...
    @y_pos.setter
    def y_pos(self, y_pos) -> None: ...
    @property
    def height(self): ...
    @height.setter
    def height(self, height) -> None: ...
    @property
    def width(self): ...
    @width.setter
    def width(self, width) -> None: ...
    @property
    def properties(self): ...
    @properties.setter
    def properties(self, properties) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
