from _typeshed import Incomplete

class XYGeom:
    LINE: str
    STEP: str
    STACKED: str
    BAR: str
    MONOTONEX: str
    STEPBEFORE: str
    STEPAFTER: str
    openapi_types: Incomplete
    attribute_map: Incomplete
    def __init__(self) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
