from netaddr.ip import _IPAddressAddr

def chr_range(low: str, high: str) -> list[str]: ...

BASE_85: list[str]
BASE_85_DICT: dict[str, int]

def ipv6_to_base85(addr: _IPAddressAddr) -> str: ...
def base85_to_ipv6(addr: str) -> str: ...
