NOT_NULL: int
PRI_KEY: int
UNIQUE_KEY: int
MULTIPLE_KEY: int
BLOB: int
UNSIGNED: int
ZEROFILL: int
BINARY: int
ENUM: int
AUTO_INCREMENT: int
TIMESTAMP: int
SET: int
PART_KEY: int
GROUP: int
UNIQUE: int
