from _typeshed import Incomplete

class DisputeGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def accept(self, dispute_id): ...
    def add_file_evidence(self, dispute_id, document_upload_id_or_request): ...
    def add_text_evidence(self, dispute_id, content_or_request): ...
    def finalize(self, dispute_id): ...
    def find(self, dispute_id): ...
    def remove_evidence(self, dispute_id, evidence_id): ...
    search_criteria: dict[Incomplete, Incomplete]
    def search(self, *query): ...
