from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class ReadyService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_ready(self, **kwargs): ...
    def get_ready_with_http_info(self, **kwargs): ...
    async def get_ready_async(self, **kwargs): ...
