from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Policy(SystemBackendMixin):
    def list_policies(self): ...
    def read_policy(self, name): ...
    def create_or_update_policy(self, name, policy, pretty_print: bool = True): ...
    def delete_policy(self, name): ...
