from _typeshed import Incomplete

class DeletePredicateRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, start: Incomplete | None = None, stop: Incomplete | None = None, predicate: Incomplete | None = None
    ) -> None: ...
    @property
    def start(self): ...
    @start.setter
    def start(self, start) -> None: ...
    @property
    def stop(self): ...
    @stop.setter
    def stop(self, stop) -> None: ...
    @property
    def predicate(self): ...
    @predicate.setter
    def predicate(self, predicate) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
