from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class SourcesService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_sources_id(self, source_id, **kwargs): ...
    def delete_sources_id_with_http_info(self, source_id, **kwargs): ...
    async def delete_sources_id_async(self, source_id, **kwargs): ...
    def get_sources(self, **kwargs): ...
    def get_sources_with_http_info(self, **kwargs): ...
    async def get_sources_async(self, **kwargs): ...
    def get_sources_id(self, source_id, **kwargs): ...
    def get_sources_id_with_http_info(self, source_id, **kwargs): ...
    async def get_sources_id_async(self, source_id, **kwargs): ...
    def get_sources_id_buckets(self, source_id, **kwargs): ...
    def get_sources_id_buckets_with_http_info(self, source_id, **kwargs): ...
    async def get_sources_id_buckets_async(self, source_id, **kwargs): ...
    def get_sources_id_health(self, source_id, **kwargs): ...
    def get_sources_id_health_with_http_info(self, source_id, **kwargs): ...
    async def get_sources_id_health_async(self, source_id, **kwargs): ...
    def patch_sources_id(self, source_id, source, **kwargs): ...
    def patch_sources_id_with_http_info(self, source_id, source, **kwargs): ...
    async def patch_sources_id_async(self, source_id, source, **kwargs): ...
    def post_sources(self, source, **kwargs): ...
    def post_sources_with_http_info(self, source, **kwargs): ...
    async def post_sources_async(self, source, **kwargs): ...
