from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def is_valid_joint_degree(joint_degrees): ...
@_dispatch
def joint_degree_graph(joint_degrees, seed: Incomplete | None = None): ...
@_dispatch
def is_valid_directed_joint_degree(in_degrees, out_degrees, nkk): ...
@_dispatch
def directed_joint_degree_graph(in_degrees, out_degrees, nkk, seed: Incomplete | None = None): ...
