from _typeshed import Incomplete

PET_DISCRETEVALUE: int
PET_RANGEDVALUE: int
PET_DEFAULTVALUE: int
PET_ENDRANGE: int
PDTF_DEFAULT: int
PDTF_MULTIPLEVALUES: int
PDTF_ISINNATE: int
PDTF_ISGROUP: int
PDTF_CANGROUPBY: int
PDTF_CANSTACKBY: int
PDTF_ISTREEPROPERTY: int
PDTF_INCLUDEINFULLTEXTQUERY: int
PDTF_ISVIEWABLE: int
PDTF_ISQUERYABLE: int
PDTF_ISSYSTEMPROPERTY: int
PDTF_MASK_ALL: int
PDVF_DEFAULT: int
PDVF_CENTERALIGN: int
PDVF_RIGHTALIGN: int
PDVF_BEGINNEWGROUP: int
PDVF_FILLAREA: int
PDVF_SORTDESCENDING: int
PDVF_SHOWONLYIFPRESENT: int
PDVF_SHOWBYDEFAULT: int
PDVF_SHOWINPRIMARYLIST: int
PDVF_SHOWINSECONDARYLIST: int
PDVF_HIDELABEL: int
PDVF_HIDDEN: int
PDVF_CANWRAP: int
PDVF_MASK_ALL: int
PDDT_STRING: int
PDDT_NUMBER: int
PDDT_BOOLEAN: int
PDDT_DATETIME: int
PDDT_ENUMERATED: int
PDGR_DISCRETE: int
PDGR_ALPHANUMERIC: int
PDGR_SIZE: int
PDGR_DYNAMIC: int
PDGR_DATE: int
PDGR_PERCENT: int
PDGR_ENUMERATED: int
PDFF_DEFAULT: int
PDFF_PREFIXNAME: int
PDFF_FILENAME: int
PDFF_ALWAYSKB: int
PDFF_RESERVED_RIGHTTOLEFT: int
PDFF_SHORTTIME: int
PDFF_LONGTIME: int
PDFF_HIDETIME: int
PDFF_SHORTDATE: int
PDFF_LONGDATE: int
PDFF_HIDEDATE: int
PDFF_RELATIVEDATE: int
PDFF_USEEDITINVITATION: int
PDFF_READONLY: int
PDFF_NOAUTOREADINGORDER: int
PDSD_GENERAL: int
PDSD_A_Z: int
PDSD_LOWEST_HIGHEST: int
PDSD_SMALLEST_BIGGEST: int
PDSD_OLDEST_NEWEST: int
PDRDT_GENERAL: int
PDRDT_DATE: int
PDRDT_SIZE: int
PDRDT_COUNT: int
PDRDT_REVISION: int
PDRDT_LENGTH: int
PDRDT_DURATION: int
PDRDT_SPEED: int
PDRDT_RATE: int
PDRDT_RATING: int
PDRDT_PRIORITY: int
PDAT_DEFAULT: int
PDAT_FIRST: int
PDAT_SUM: int
PDAT_AVERAGE: int
PDAT_DATERANGE: int
PDAT_UNION: int
PDAT_MAX: int
PDAT_MIN: int
PDCOT_NONE: int
PDCOT_STRING: int
PDCOT_SIZE: int
PDCOT_DATETIME: int
PDCOT_BOOLEAN: int
PDCOT_NUMBER: int
PDSIF_DEFAULT: int
PDSIF_ININVERTEDINDEX: int
PDSIF_ISCOLUMN: int
PDSIF_ISCOLUMNSPARSE: int
PDCIT_NONE: int
PDCIT_ONDISK: int
PDCIT_INMEMORY: int
PDEF_ALL: int
PDEF_SYSTEM: int
PDEF_NONSYSTEM: int
PDEF_VIEWABLE: int
PDEF_QUERYABLE: int
PDEF_INFULLTEXTQUERY: int
PDEF_COLUMN: int
PSC_NORMAL: int
PSC_NOTINSOURCE: int
PSC_DIRTY: int
COP_IMPLICIT: int
COP_EQUAL: int
COP_NOTEQUAL: int
COP_LESSTHAN: int
COP_GREATERTHAN: int
COP_LESSTHANOREQUAL: int
COP_GREATERTHANOREQUAL: int
COP_VALUE_STARTSWITH: int
COP_VALUE_ENDSWITH: int
COP_VALUE_CONTAINS: int
COP_VALUE_NOTCONTAINS: int
COP_DOSWILDCARDS: int
COP_WORD_EQUAL: int
COP_WORD_STARTSWITH: int
COP_APPLICATION_SPECIFIC: int
FPSPS_READONLY: int
PKEY_PIDSTR_MAX: int
GUIDSTRING_MAX: Incomplete
PKEYSTR_MAX: Incomplete
PKEY_Audio_ChannelCount: Incomplete
PKEY_Audio_Compression: Incomplete
PKEY_Audio_EncodingBitrate: Incomplete
PKEY_Audio_Format: Incomplete
PKEY_Audio_IsVariableBitRate: Incomplete
PKEY_Audio_PeakValue: Incomplete
PKEY_Audio_SampleRate: Incomplete
PKEY_Audio_SampleSize: Incomplete
PKEY_Audio_StreamName: Incomplete
PKEY_Audio_StreamNumber: Incomplete
PKEY_Calendar_Duration: Incomplete
PKEY_Calendar_IsOnline: Incomplete
PKEY_Calendar_IsRecurring: Incomplete
PKEY_Calendar_Location: Incomplete
PKEY_Calendar_OptionalAttendeeAddresses: Incomplete
PKEY_Calendar_OptionalAttendeeNames: Incomplete
PKEY_Calendar_OrganizerAddress: Incomplete
PKEY_Calendar_OrganizerName: Incomplete
PKEY_Calendar_ReminderTime: Incomplete
PKEY_Calendar_RequiredAttendeeAddresses: Incomplete
PKEY_Calendar_RequiredAttendeeNames: Incomplete
PKEY_Calendar_Resources: Incomplete
PKEY_Calendar_ShowTimeAs: Incomplete
PKEY_Calendar_ShowTimeAsText: Incomplete
PKEY_Communication_AccountName: Incomplete
PKEY_Communication_Suffix: Incomplete
PKEY_Communication_TaskStatus: Incomplete
PKEY_Communication_TaskStatusText: Incomplete
PKEY_Computer_DecoratedFreeSpace: Incomplete
PKEY_Contact_Anniversary: Incomplete
PKEY_Contact_AssistantName: Incomplete
PKEY_Contact_AssistantTelephone: Incomplete
PKEY_Contact_Birthday: Incomplete
PKEY_Contact_BusinessAddress: Incomplete
PKEY_Contact_BusinessAddressCity: Incomplete
PKEY_Contact_BusinessAddressCountry: Incomplete
PKEY_Contact_BusinessAddressPostalCode: Incomplete
PKEY_Contact_BusinessAddressPostOfficeBox: Incomplete
PKEY_Contact_BusinessAddressState: Incomplete
PKEY_Contact_BusinessAddressStreet: Incomplete
PKEY_Contact_BusinessFaxNumber: Incomplete
PKEY_Contact_BusinessHomePage: Incomplete
PKEY_Contact_BusinessTelephone: Incomplete
PKEY_Contact_CallbackTelephone: Incomplete
PKEY_Contact_CarTelephone: Incomplete
PKEY_Contact_Children: Incomplete
PKEY_Contact_CompanyMainTelephone: Incomplete
PKEY_Contact_Department: Incomplete
PKEY_Contact_EmailAddress: Incomplete
PKEY_Contact_EmailAddress2: Incomplete
PKEY_Contact_EmailAddress3: Incomplete
PKEY_Contact_EmailAddresses: Incomplete
PKEY_Contact_EmailName: Incomplete
PKEY_Contact_FileAsName: Incomplete
PKEY_Contact_FirstName: Incomplete
PKEY_Contact_FullName: Incomplete
PKEY_Contact_Gender: Incomplete
PKEY_Contact_Hobbies: Incomplete
PKEY_Contact_HomeAddress: Incomplete
PKEY_Contact_HomeAddressCity: Incomplete
PKEY_Contact_HomeAddressCountry: Incomplete
PKEY_Contact_HomeAddressPostalCode: Incomplete
PKEY_Contact_HomeAddressPostOfficeBox: Incomplete
PKEY_Contact_HomeAddressState: Incomplete
PKEY_Contact_HomeAddressStreet: Incomplete
PKEY_Contact_HomeFaxNumber: Incomplete
PKEY_Contact_HomeTelephone: Incomplete
PKEY_Contact_IMAddress: Incomplete
PKEY_Contact_Initials: Incomplete
PKEY_Contact_JA_CompanyNamePhonetic: Incomplete
PKEY_Contact_JA_FirstNamePhonetic: Incomplete
PKEY_Contact_JA_LastNamePhonetic: Incomplete
PKEY_Contact_JobTitle: Incomplete
PKEY_Contact_Label: Incomplete
PKEY_Contact_LastName: Incomplete
PKEY_Contact_MailingAddress: Incomplete
PKEY_Contact_MiddleName: Incomplete
PKEY_Contact_MobileTelephone: Incomplete
PKEY_Contact_NickName: Incomplete
PKEY_Contact_OfficeLocation: Incomplete
PKEY_Contact_OtherAddress: Incomplete
PKEY_Contact_OtherAddressCity: Incomplete
PKEY_Contact_OtherAddressCountry: Incomplete
PKEY_Contact_OtherAddressPostalCode: Incomplete
PKEY_Contact_OtherAddressPostOfficeBox: Incomplete
PKEY_Contact_OtherAddressState: Incomplete
PKEY_Contact_OtherAddressStreet: Incomplete
PKEY_Contact_PagerTelephone: Incomplete
PKEY_Contact_PersonalTitle: Incomplete
PKEY_Contact_PrimaryAddressCity: Incomplete
PKEY_Contact_PrimaryAddressCountry: Incomplete
PKEY_Contact_PrimaryAddressPostalCode: Incomplete
PKEY_Contact_PrimaryAddressPostOfficeBox: Incomplete
PKEY_Contact_PrimaryAddressState: Incomplete
PKEY_Contact_PrimaryAddressStreet: Incomplete
PKEY_Contact_PrimaryEmailAddress: Incomplete
PKEY_Contact_PrimaryTelephone: Incomplete
PKEY_Contact_Profession: Incomplete
PKEY_Contact_SpouseName: Incomplete
PKEY_Contact_Suffix: Incomplete
PKEY_Contact_TelexNumber: Incomplete
PKEY_Contact_TTYTDDTelephone: Incomplete
PKEY_Contact_WebPage: Incomplete
PKEY_AcquisitionID: Incomplete
PKEY_ApplicationName: Incomplete
PKEY_Author: Incomplete
PKEY_Capacity: Incomplete
PKEY_Category: Incomplete
PKEY_Comment: Incomplete
PKEY_Company: Incomplete
PKEY_ComputerName: Incomplete
PKEY_ContainedItems: Incomplete
PKEY_ContentStatus: Incomplete
PKEY_ContentType: Incomplete
PKEY_Copyright: Incomplete
PKEY_DateAccessed: Incomplete
PKEY_DateAcquired: Incomplete
PKEY_DateArchived: Incomplete
PKEY_DateCompleted: Incomplete
PKEY_DateCreated: Incomplete
PKEY_DateImported: Incomplete
PKEY_DateModified: Incomplete
PKEY_DueDate: Incomplete
PKEY_EndDate: Incomplete
PKEY_FileAllocationSize: Incomplete
PKEY_FileAttributes: Incomplete
PKEY_FileCount: Incomplete
PKEY_FileDescription: Incomplete
PKEY_FileExtension: Incomplete
PKEY_FileFRN: Incomplete
PKEY_FileName: Incomplete
PKEY_FileOwner: Incomplete
PKEY_FileVersion: Incomplete
PKEY_FindData: Incomplete
PKEY_FlagColor: Incomplete
PKEY_FlagColorText: Incomplete
PKEY_FlagStatus: Incomplete
PKEY_FlagStatusText: Incomplete
PKEY_FreeSpace: Incomplete
PKEY_Identity: Incomplete
PKEY_Importance: Incomplete
PKEY_ImportanceText: Incomplete
PKEY_IsAttachment: Incomplete
PKEY_IsDeleted: Incomplete
PKEY_IsFlagged: Incomplete
PKEY_IsFlaggedComplete: Incomplete
PKEY_IsIncomplete: Incomplete
PKEY_IsRead: Incomplete
PKEY_IsSendToTarget: Incomplete
PKEY_IsShared: Incomplete
PKEY_ItemAuthors: Incomplete
PKEY_ItemDate: Incomplete
PKEY_ItemFolderNameDisplay: Incomplete
PKEY_ItemFolderPathDisplay: Incomplete
PKEY_ItemFolderPathDisplayNarrow: Incomplete
PKEY_ItemName: Incomplete
PKEY_ItemNameDisplay: Incomplete
PKEY_ItemNamePrefix: Incomplete
PKEY_ItemParticipants: Incomplete
PKEY_ItemPathDisplay: Incomplete
PKEY_ItemPathDisplayNarrow: Incomplete
PKEY_ItemType: Incomplete
PKEY_ItemTypeText: Incomplete
PKEY_ItemUrl: Incomplete
PKEY_Keywords: Incomplete
PKEY_Kind: Incomplete
PKEY_KindText: Incomplete
PKEY_Language: Incomplete
PKEY_MileageInformation: Incomplete
PKEY_MIMEType: Incomplete
PKEY_Null: Incomplete
PKEY_OfflineAvailability: Incomplete
PKEY_OfflineStatus: Incomplete
PKEY_OriginalFileName: Incomplete
PKEY_ParentalRating: Incomplete
PKEY_ParentalRatingReason: Incomplete
PKEY_ParentalRatingsOrganization: Incomplete
PKEY_ParsingBindContext: Incomplete
PKEY_ParsingName: Incomplete
PKEY_ParsingPath: Incomplete
PKEY_PerceivedType: Incomplete
PKEY_PercentFull: Incomplete
PKEY_Priority: Incomplete
PKEY_PriorityText: Incomplete
PKEY_Project: Incomplete
PKEY_ProviderItemID: Incomplete
PKEY_Rating: Incomplete
PKEY_RatingText: Incomplete
PKEY_Sensitivity: Incomplete
PKEY_SensitivityText: Incomplete
PKEY_SFGAOFlags: Incomplete
PKEY_SharedWith: Incomplete
PKEY_ShareUserRating: Incomplete
PKEY_Shell_OmitFromView: Incomplete
PKEY_SimpleRating: Incomplete
PKEY_Size: Incomplete
PKEY_SoftwareUsed: Incomplete
PKEY_SourceItem: Incomplete
PKEY_StartDate: Incomplete
PKEY_Status: Incomplete
PKEY_Subject: Incomplete
PKEY_Thumbnail: Incomplete
PKEY_ThumbnailCacheId: Incomplete
PKEY_ThumbnailStream: Incomplete
PKEY_Title: Incomplete
PKEY_TotalFileSize: Incomplete
PKEY_Trademarks: Incomplete
PKEY_Document_ByteCount: Incomplete
PKEY_Document_CharacterCount: Incomplete
PKEY_Document_ClientID: Incomplete
PKEY_Document_Contributor: Incomplete
PKEY_Document_DateCreated: Incomplete
PKEY_Document_DatePrinted: Incomplete
PKEY_Document_DateSaved: Incomplete
PKEY_Document_Division: Incomplete
PKEY_Document_DocumentID: Incomplete
PKEY_Document_HiddenSlideCount: Incomplete
PKEY_Document_LastAuthor: Incomplete
PKEY_Document_LineCount: Incomplete
PKEY_Document_Manager: Incomplete
PKEY_Document_MultimediaClipCount: Incomplete
PKEY_Document_NoteCount: Incomplete
PKEY_Document_PageCount: Incomplete
PKEY_Document_ParagraphCount: Incomplete
PKEY_Document_PresentationFormat: Incomplete
PKEY_Document_RevisionNumber: Incomplete
PKEY_Document_Security: Incomplete
PKEY_Document_SlideCount: Incomplete
PKEY_Document_Template: Incomplete
PKEY_Document_TotalEditingTime: Incomplete
PKEY_Document_Version: Incomplete
PKEY_Document_WordCount: Incomplete
PKEY_DRM_DatePlayExpires: Incomplete
PKEY_DRM_DatePlayStarts: Incomplete
PKEY_DRM_Description: Incomplete
PKEY_DRM_IsProtected: Incomplete
PKEY_DRM_PlayCount: Incomplete
PKEY_GPS_Altitude: Incomplete
PKEY_GPS_AltitudeDenominator: Incomplete
PKEY_GPS_AltitudeNumerator: Incomplete
PKEY_GPS_AltitudeRef: Incomplete
PKEY_GPS_AreaInformation: Incomplete
PKEY_GPS_Date: Incomplete
PKEY_GPS_DestBearing: Incomplete
PKEY_GPS_DestBearingDenominator: Incomplete
PKEY_GPS_DestBearingNumerator: Incomplete
PKEY_GPS_DestBearingRef: Incomplete
PKEY_GPS_DestDistance: Incomplete
PKEY_GPS_DestDistanceDenominator: Incomplete
PKEY_GPS_DestDistanceNumerator: Incomplete
PKEY_GPS_DestDistanceRef: Incomplete
PKEY_GPS_DestLatitude: Incomplete
PKEY_GPS_DestLatitudeDenominator: Incomplete
PKEY_GPS_DestLatitudeNumerator: Incomplete
PKEY_GPS_DestLatitudeRef: Incomplete
PKEY_GPS_DestLongitude: Incomplete
PKEY_GPS_DestLongitudeDenominator: Incomplete
PKEY_GPS_DestLongitudeNumerator: Incomplete
PKEY_GPS_DestLongitudeRef: Incomplete
PKEY_GPS_Differential: Incomplete
PKEY_GPS_DOP: Incomplete
PKEY_GPS_DOPDenominator: Incomplete
PKEY_GPS_DOPNumerator: Incomplete
PKEY_GPS_ImgDirection: Incomplete
PKEY_GPS_ImgDirectionDenominator: Incomplete
PKEY_GPS_ImgDirectionNumerator: Incomplete
PKEY_GPS_ImgDirectionRef: Incomplete
PKEY_GPS_Latitude: Incomplete
PKEY_GPS_LatitudeDenominator: Incomplete
PKEY_GPS_LatitudeNumerator: Incomplete
PKEY_GPS_LatitudeRef: Incomplete
PKEY_GPS_Longitude: Incomplete
PKEY_GPS_LongitudeDenominator: Incomplete
PKEY_GPS_LongitudeNumerator: Incomplete
PKEY_GPS_LongitudeRef: Incomplete
PKEY_GPS_MapDatum: Incomplete
PKEY_GPS_MeasureMode: Incomplete
PKEY_GPS_ProcessingMethod: Incomplete
PKEY_GPS_Satellites: Incomplete
PKEY_GPS_Speed: Incomplete
PKEY_GPS_SpeedDenominator: Incomplete
PKEY_GPS_SpeedNumerator: Incomplete
PKEY_GPS_SpeedRef: Incomplete
PKEY_GPS_Status: Incomplete
PKEY_GPS_Track: Incomplete
PKEY_GPS_TrackDenominator: Incomplete
PKEY_GPS_TrackNumerator: Incomplete
PKEY_GPS_TrackRef: Incomplete
PKEY_GPS_VersionID: Incomplete
PKEY_Image_BitDepth: Incomplete
PKEY_Image_ColorSpace: Incomplete
PKEY_Image_CompressedBitsPerPixel: Incomplete
PKEY_Image_CompressedBitsPerPixelDenominator: Incomplete
PKEY_Image_CompressedBitsPerPixelNumerator: Incomplete
PKEY_Image_Compression: Incomplete
PKEY_Image_CompressionText: Incomplete
PKEY_Image_Dimensions: Incomplete
PKEY_Image_HorizontalResolution: Incomplete
PKEY_Image_HorizontalSize: Incomplete
PKEY_Image_ImageID: Incomplete
PKEY_Image_ResolutionUnit: Incomplete
PKEY_Image_VerticalResolution: Incomplete
PKEY_Image_VerticalSize: Incomplete
PKEY_Journal_Contacts: Incomplete
PKEY_Journal_EntryType: Incomplete
PKEY_Link_Comment: Incomplete
PKEY_Link_DateVisited: Incomplete
PKEY_Link_Description: Incomplete
PKEY_Link_Status: Incomplete
PKEY_Link_TargetExtension: Incomplete
PKEY_Link_TargetParsingPath: Incomplete
PKEY_Link_TargetSFGAOFlags: Incomplete
PKEY_Media_AuthorUrl: Incomplete
PKEY_Media_AverageLevel: Incomplete
PKEY_Media_ClassPrimaryID: Incomplete
PKEY_Media_ClassSecondaryID: Incomplete
PKEY_Media_CollectionGroupID: Incomplete
PKEY_Media_CollectionID: Incomplete
PKEY_Media_ContentDistributor: Incomplete
PKEY_Media_ContentID: Incomplete
PKEY_Media_CreatorApplication: Incomplete
PKEY_Media_CreatorApplicationVersion: Incomplete
PKEY_Media_DateEncoded: Incomplete
PKEY_Media_DateReleased: Incomplete
PKEY_Media_Duration: Incomplete
PKEY_Media_DVDID: Incomplete
PKEY_Media_EncodedBy: Incomplete
PKEY_Media_EncodingSettings: Incomplete
PKEY_Media_FrameCount: Incomplete
PKEY_Media_MCDI: Incomplete
PKEY_Media_MetadataContentProvider: Incomplete
PKEY_Media_Producer: Incomplete
PKEY_Media_PromotionUrl: Incomplete
PKEY_Media_ProtectionType: Incomplete
PKEY_Media_ProviderRating: Incomplete
PKEY_Media_ProviderStyle: Incomplete
PKEY_Media_Publisher: Incomplete
PKEY_Media_SubscriptionContentId: Incomplete
PKEY_Media_SubTitle: Incomplete
PKEY_Media_UniqueFileIdentifier: Incomplete
PKEY_Media_UserNoAutoInfo: Incomplete
PKEY_Media_UserWebUrl: Incomplete
PKEY_Media_Writer: Incomplete
PKEY_Media_Year: Incomplete
PKEY_Message_AttachmentContents: Incomplete
PKEY_Message_AttachmentNames: Incomplete
PKEY_Message_BccAddress: Incomplete
PKEY_Message_BccName: Incomplete
PKEY_Message_CcAddress: Incomplete
PKEY_Message_CcName: Incomplete
PKEY_Message_ConversationID: Incomplete
PKEY_Message_ConversationIndex: Incomplete
PKEY_Message_DateReceived: Incomplete
PKEY_Message_DateSent: Incomplete
PKEY_Message_FromAddress: Incomplete
PKEY_Message_FromName: Incomplete
PKEY_Message_HasAttachments: Incomplete
PKEY_Message_IsFwdOrReply: Incomplete
PKEY_Message_MessageClass: Incomplete
PKEY_Message_SenderAddress: Incomplete
PKEY_Message_SenderName: Incomplete
PKEY_Message_Store: Incomplete
PKEY_Message_ToAddress: Incomplete
PKEY_Message_ToDoTitle: Incomplete
PKEY_Message_ToName: Incomplete
PKEY_Music_AlbumArtist: Incomplete
PKEY_Music_AlbumTitle: Incomplete
PKEY_Music_Artist: Incomplete
PKEY_Music_BeatsPerMinute: Incomplete
PKEY_Music_Composer: Incomplete
PKEY_Music_Conductor: Incomplete
PKEY_Music_ContentGroupDescription: Incomplete
PKEY_Music_Genre: Incomplete
PKEY_Music_InitialKey: Incomplete
PKEY_Music_Lyrics: Incomplete
PKEY_Music_Mood: Incomplete
PKEY_Music_PartOfSet: Incomplete
PKEY_Music_Period: Incomplete
PKEY_Music_SynchronizedLyrics: Incomplete
PKEY_Music_TrackNumber: Incomplete
PKEY_Note_Color: Incomplete
PKEY_Note_ColorText: Incomplete
PKEY_Photo_Aperture: Incomplete
PKEY_Photo_ApertureDenominator: Incomplete
PKEY_Photo_ApertureNumerator: Incomplete
PKEY_Photo_Brightness: Incomplete
PKEY_Photo_BrightnessDenominator: Incomplete
PKEY_Photo_BrightnessNumerator: Incomplete
PKEY_Photo_CameraManufacturer: Incomplete
PKEY_Photo_CameraModel: Incomplete
PKEY_Photo_CameraSerialNumber: Incomplete
PKEY_Photo_Contrast: Incomplete
PKEY_Photo_ContrastText: Incomplete
PKEY_Photo_DateTaken: Incomplete
PKEY_Photo_DigitalZoom: Incomplete
PKEY_Photo_DigitalZoomDenominator: Incomplete
PKEY_Photo_DigitalZoomNumerator: Incomplete
PKEY_Photo_Event: Incomplete
PKEY_Photo_EXIFVersion: Incomplete
PKEY_Photo_ExposureBias: Incomplete
PKEY_Photo_ExposureBiasDenominator: Incomplete
PKEY_Photo_ExposureBiasNumerator: Incomplete
PKEY_Photo_ExposureIndex: Incomplete
PKEY_Photo_ExposureIndexDenominator: Incomplete
PKEY_Photo_ExposureIndexNumerator: Incomplete
PKEY_Photo_ExposureProgram: Incomplete
PKEY_Photo_ExposureProgramText: Incomplete
PKEY_Photo_ExposureTime: Incomplete
PKEY_Photo_ExposureTimeDenominator: Incomplete
PKEY_Photo_ExposureTimeNumerator: Incomplete
PKEY_Photo_Flash: Incomplete
PKEY_Photo_FlashEnergy: Incomplete
PKEY_Photo_FlashEnergyDenominator: Incomplete
PKEY_Photo_FlashEnergyNumerator: Incomplete
PKEY_Photo_FlashManufacturer: Incomplete
PKEY_Photo_FlashModel: Incomplete
PKEY_Photo_FlashText: Incomplete
PKEY_Photo_FNumber: Incomplete
PKEY_Photo_FNumberDenominator: Incomplete
PKEY_Photo_FNumberNumerator: Incomplete
PKEY_Photo_FocalLength: Incomplete
PKEY_Photo_FocalLengthDenominator: Incomplete
PKEY_Photo_FocalLengthInFilm: Incomplete
PKEY_Photo_FocalLengthNumerator: Incomplete
PKEY_Photo_FocalPlaneXResolution: Incomplete
PKEY_Photo_FocalPlaneXResolutionDenominator: Incomplete
PKEY_Photo_FocalPlaneXResolutionNumerator: Incomplete
PKEY_Photo_FocalPlaneYResolution: Incomplete
PKEY_Photo_FocalPlaneYResolutionDenominator: Incomplete
PKEY_Photo_FocalPlaneYResolutionNumerator: Incomplete
PKEY_Photo_GainControl: Incomplete
PKEY_Photo_GainControlDenominator: Incomplete
PKEY_Photo_GainControlNumerator: Incomplete
PKEY_Photo_GainControlText: Incomplete
PKEY_Photo_ISOSpeed: Incomplete
PKEY_Photo_LensManufacturer: Incomplete
PKEY_Photo_LensModel: Incomplete
PKEY_Photo_LightSource: Incomplete
PKEY_Photo_MakerNote: Incomplete
PKEY_Photo_MakerNoteOffset: Incomplete
PKEY_Photo_MaxAperture: Incomplete
PKEY_Photo_MaxApertureDenominator: Incomplete
PKEY_Photo_MaxApertureNumerator: Incomplete
PKEY_Photo_MeteringMode: Incomplete
PKEY_Photo_MeteringModeText: Incomplete
PKEY_Photo_Orientation: Incomplete
PKEY_Photo_OrientationText: Incomplete
PKEY_Photo_PhotometricInterpretation: Incomplete
PKEY_Photo_PhotometricInterpretationText: Incomplete
PKEY_Photo_ProgramMode: Incomplete
PKEY_Photo_ProgramModeText: Incomplete
PKEY_Photo_RelatedSoundFile: Incomplete
PKEY_Photo_Saturation: Incomplete
PKEY_Photo_SaturationText: Incomplete
PKEY_Photo_Sharpness: Incomplete
PKEY_Photo_SharpnessText: Incomplete
PKEY_Photo_ShutterSpeed: Incomplete
PKEY_Photo_ShutterSpeedDenominator: Incomplete
PKEY_Photo_ShutterSpeedNumerator: Incomplete
PKEY_Photo_SubjectDistance: Incomplete
PKEY_Photo_SubjectDistanceDenominator: Incomplete
PKEY_Photo_SubjectDistanceNumerator: Incomplete
PKEY_Photo_TranscodedForSync: Incomplete
PKEY_Photo_WhiteBalance: Incomplete
PKEY_Photo_WhiteBalanceText: Incomplete
PKEY_PropGroup_Advanced: Incomplete
PKEY_PropGroup_Audio: Incomplete
PKEY_PropGroup_Calendar: Incomplete
PKEY_PropGroup_Camera: Incomplete
PKEY_PropGroup_Contact: Incomplete
PKEY_PropGroup_Content: Incomplete
PKEY_PropGroup_Description: Incomplete
PKEY_PropGroup_FileSystem: Incomplete
PKEY_PropGroup_General: Incomplete
PKEY_PropGroup_GPS: Incomplete
PKEY_PropGroup_Image: Incomplete
PKEY_PropGroup_Media: Incomplete
PKEY_PropGroup_MediaAdvanced: Incomplete
PKEY_PropGroup_Message: Incomplete
PKEY_PropGroup_Music: Incomplete
PKEY_PropGroup_Origin: Incomplete
PKEY_PropGroup_PhotoAdvanced: Incomplete
PKEY_PropGroup_RecordedTV: Incomplete
PKEY_PropGroup_Video: Incomplete
PKEY_PropList_ConflictPrompt: Incomplete
PKEY_PropList_ExtendedTileInfo: Incomplete
PKEY_PropList_FileOperationPrompt: Incomplete
PKEY_PropList_FullDetails: Incomplete
PKEY_PropList_InfoTip: Incomplete
PKEY_PropList_NonPersonal: Incomplete
PKEY_PropList_PreviewDetails: Incomplete
PKEY_PropList_PreviewTitle: Incomplete
PKEY_PropList_QuickTip: Incomplete
PKEY_PropList_TileInfo: Incomplete
PKEY_PropList_XPDetailsPanel: Incomplete
PKEY_RecordedTV_ChannelNumber: Incomplete
PKEY_RecordedTV_Credits: Incomplete
PKEY_RecordedTV_DateContentExpires: Incomplete
PKEY_RecordedTV_EpisodeName: Incomplete
PKEY_RecordedTV_IsATSCContent: Incomplete
PKEY_RecordedTV_IsClosedCaptioningAvailable: Incomplete
PKEY_RecordedTV_IsDTVContent: Incomplete
PKEY_RecordedTV_IsHDContent: Incomplete
PKEY_RecordedTV_IsRepeatBroadcast: Incomplete
PKEY_RecordedTV_IsSAP: Incomplete
PKEY_RecordedTV_NetworkAffiliation: Incomplete
PKEY_RecordedTV_OriginalBroadcastDate: Incomplete
PKEY_RecordedTV_ProgramDescription: Incomplete
PKEY_RecordedTV_RecordingTime: Incomplete
PKEY_RecordedTV_StationCallSign: Incomplete
PKEY_RecordedTV_StationName: Incomplete
PKEY_Search_AutoSummary: Incomplete
PKEY_Search_ContainerHash: Incomplete
PKEY_Search_Contents: Incomplete
PKEY_Search_EntryID: Incomplete
PKEY_Search_GatherTime: Incomplete
PKEY_Search_IsClosedDirectory: Incomplete
PKEY_Search_IsFullyContained: Incomplete
PKEY_Search_QueryFocusedSummary: Incomplete
PKEY_Search_Rank: Incomplete
PKEY_Search_Store: Incomplete
PKEY_Search_UrlToIndex: Incomplete
PKEY_Search_UrlToIndexWithModificationTime: Incomplete
PKEY_DescriptionID: Incomplete
PKEY_Link_TargetSFGAOFlagsStrings: Incomplete
PKEY_Link_TargetUrl: Incomplete
PKEY_Shell_SFGAOFlagsStrings: Incomplete
PKEY_Software_DateLastUsed: Incomplete
PKEY_Software_ProductName: Incomplete
PKEY_Sync_Comments: Incomplete
PKEY_Sync_ConflictDescription: Incomplete
PKEY_Sync_ConflictFirstLocation: Incomplete
PKEY_Sync_ConflictSecondLocation: Incomplete
PKEY_Sync_HandlerCollectionID: Incomplete
PKEY_Sync_HandlerID: Incomplete
PKEY_Sync_HandlerName: Incomplete
PKEY_Sync_HandlerType: Incomplete
PKEY_Sync_HandlerTypeLabel: Incomplete
PKEY_Sync_ItemID: Incomplete
PKEY_Sync_ItemName: Incomplete
PKEY_Task_BillingInformation: Incomplete
PKEY_Task_CompletionStatus: Incomplete
PKEY_Task_Owner: Incomplete
PKEY_Video_Compression: Incomplete
PKEY_Video_Director: Incomplete
PKEY_Video_EncodingBitrate: Incomplete
PKEY_Video_FourCC: Incomplete
PKEY_Video_FrameHeight: Incomplete
PKEY_Video_FrameRate: Incomplete
PKEY_Video_FrameWidth: Incomplete
PKEY_Video_HorizontalAspectRatio: Incomplete
PKEY_Video_SampleSize: Incomplete
PKEY_Video_StreamName: Incomplete
PKEY_Video_StreamNumber: Incomplete
PKEY_Video_TotalBitrate: Incomplete
PKEY_Video_VerticalAspectRatio: Incomplete
PKEY_Volume_FileSystem: Incomplete
PKEY_Volume_IsMappedDrive: Incomplete
PKEY_Volume_IsRoot: Incomplete
PKEY_AppUserModel_RelaunchCommand: Incomplete
PKEY_AppUserModel_RelaunchIconResource: Incomplete
PKEY_AppUserModel_RelaunchDisplayNameResource: Incomplete
PKEY_AppUserModel_ID: Incomplete
PKEY_AppUserModel_IsDestListSeparator: Incomplete
PKEY_AppUserModel_ExcludeFromShowInNewInstall: Incomplete
PKEY_AppUserModel_PreventPinning: Incomplete
PKA_SET: int
PKA_APPEND: int
PKA_DELETE: int
