from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class ReplicationsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_replication_by_id(self, replication_id, **kwargs): ...
    def delete_replication_by_id_with_http_info(self, replication_id, **kwargs): ...
    async def delete_replication_by_id_async(self, replication_id, **kwargs): ...
    def get_replication_by_id(self, replication_id, **kwargs): ...
    def get_replication_by_id_with_http_info(self, replication_id, **kwargs): ...
    async def get_replication_by_id_async(self, replication_id, **kwargs): ...
    def get_replications(self, org_id, **kwargs): ...
    def get_replications_with_http_info(self, org_id, **kwargs): ...
    async def get_replications_async(self, org_id, **kwargs): ...
    def patch_replication_by_id(self, replication_id, replication_update_request, **kwargs): ...
    def patch_replication_by_id_with_http_info(self, replication_id, replication_update_request, **kwargs): ...
    async def patch_replication_by_id_async(self, replication_id, replication_update_request, **kwargs): ...
    def post_replication(self, replication_creation_request, **kwargs): ...
    def post_replication_with_http_info(self, replication_creation_request, **kwargs): ...
    async def post_replication_async(self, replication_creation_request, **kwargs): ...
    def post_validate_replication_by_id(self, replication_id, **kwargs): ...
    def post_validate_replication_by_id_with_http_info(self, replication_id, **kwargs): ...
    async def post_validate_replication_by_id_async(self, replication_id, **kwargs): ...
