from networkx.utils.backends import _dispatch

@_dispatch
def kl_connected_subgraph(G, k, l, low_memory: bool = False, same_as_graph: bool = False): ...
@_dispatch
def is_kl_connected(G, k, l, low_memory: bool = False): ...
