from _typeshed import Incomplete

class StackAssociations:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, kind: Incomplete | None = None, meta_name: Incomplete | None = None) -> None: ...
    @property
    def kind(self): ...
    @kind.setter
    def kind(self, kind) -> None: ...
    @property
    def meta_name(self): ...
    @meta_name.setter
    def meta_name(self, meta_name) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
