from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def from_graph6_bytes(bytes_in): ...
def to_graph6_bytes(G, nodes: Incomplete | None = None, header: bool = True): ...
@_dispatch
def read_graph6(path): ...
def write_graph6(G, path, nodes: Incomplete | None = None, header: bool = True): ...
