from _typeshed import Incomplete

from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Lease(SystemBackendMixin):
    def read_lease(self, lease_id): ...
    def list_leases(self, prefix): ...
    def renew_lease(self, lease_id, increment: Incomplete | None = None): ...
    def revoke_lease(self, lease_id): ...
    def revoke_prefix(self, prefix): ...
    def revoke_force(self, prefix): ...
