from typing import IO, AnyStr, Generic, Literal

class ContainerIO(Generic[AnyStr]):
    fh: IO[AnyStr]
    pos: int
    offset: int
    length: int
    def __init__(self, file: IO[AnyStr], offset: int, length: int) -> None: ...
    def isatty(self) -> bool: ...
    def seek(self, offset: int, mode: Literal[0, 1, 2] = 0) -> None: ...
    def tell(self) -> int: ...
    def read(self, n: int = 0) -> AnyStr: ...
    def readline(self) -> AnyStr: ...
    def readlines(self) -> list[AnyStr]: ...
