STATE_KEY: int
STATE_VALUE: int

def md5_h(value): ...
def md5_kd(k, s): ...
def md5_hex(value): ...
def md5_hmac(k, s): ...
def sasl_digest_md5(connection, controls): ...
def decode_directives(directives_string): ...
