from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def hnm_harary_graph(n, m, create_using: Incomplete | None = None): ...
@_dispatch
def hkn_harary_graph(k, n, create_using: Incomplete | None = None): ...
