from _typeshed import Incomplete

class ASTResponse:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, ast: Incomplete | None = None) -> None: ...
    @property
    def ast(self): ...
    @ast.setter
    def ast(self, ast) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
