from types import ModuleType
from typing import Any, NoReturn

def support_deprecated_txt_arg(fn): ...

class WarnOnDeprecatedModuleAttributes(ModuleType):
    def __call__(self) -> NoReturn: ...
    def __getattr__(self, name: str) -> Any: ...
    def __setattr__(self, name: str, value: Any) -> None: ...

def get_stack_level() -> int: ...
