from _typeshed import Incomplete

class SettlementBatchSummaryGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def generate(self, settlement_date, group_by_custom_field: Incomplete | None = None): ...
