class InvalidSamplingManifestError(Exception): ...
class SegmentNotFoundException(Exception): ...
class InvalidDaemonAddressException(Exception): ...
class SegmentNameMissingException(Exception): ...
class SubsegmentNameMissingException(Exception): ...
class FacadeSegmentMutationException(Exception): ...
class MissingPluginNames(Exception): ...
class AlreadyEndedException(Exception): ...
