from _typeshed import Incomplete
from typing import Any

class _PasslibRegistryProxy:
    __name__: str
    __package__: Any
    def __getattr__(self, attr: str): ...
    def __setattr__(self, attr: str, value) -> None: ...
    def __dir__(self): ...

def register_crypt_handler_path(name, path) -> None: ...
def register_crypt_handler(handler, force: bool = False, _attr: Incomplete | None = None) -> None: ...
def get_crypt_handler(name, default=...): ...
def list_crypt_handlers(loaded_only: bool = False): ...
