from _typeshed import Incomplete

class SignatureService:
    private_key: Incomplete
    hmac_hash: Incomplete
    def __init__(self, private_key, hashfunc=...) -> None: ...
    def sign(self, data): ...
    def hash(self, data): ...
