from _typeshed import Incomplete

class TemplateKind:
    BUCKET: str
    CHECK: str
    CHECKDEADMAN: str
    CHECKTHRESHOLD: str
    DASHBOARD: str
    LABEL: str
    NOTIFICATIONENDPOINT: str
    NOTIFICATIONENDPOINTHTTP: str
    NOTIFICATIONENDPOINTPAGERDUTY: str
    NOTIFICATIONENDPOINTSLACK: str
    NOTIFICATIONRULE: str
    TASK: str
    TELEGRAF: str
    VARIABLE: str
    openapi_types: Incomplete
    attribute_map: Incomplete
    def __init__(self) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
