from _typeshed import Incomplete

class ModeDescriptor:
    mode: Incomplete
    bands: Incomplete
    basemode: Incomplete
    basetype: Incomplete
    def __init__(self, mode, bands, basemode, basetype, typestr) -> None: ...

def getmode(mode): ...
