from networkx.utils.backends import _dispatch

@_dispatch
def union_all(graphs, rename=()): ...
@_dispatch
def disjoint_union_all(graphs): ...
@_dispatch
def compose_all(graphs): ...
@_dispatch
def intersection_all(graphs): ...
