from _typeshed import Incomplete

from influxdb_client.domain.view_properties import ViewProperties

class TableViewProperties(ViewProperties):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        queries: Incomplete | None = None,
        colors: Incomplete | None = None,
        shape: Incomplete | None = None,
        note: Incomplete | None = None,
        show_note_when_empty: Incomplete | None = None,
        table_options: Incomplete | None = None,
        field_options: Incomplete | None = None,
        time_format: Incomplete | None = None,
        decimal_places: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def queries(self): ...
    @queries.setter
    def queries(self, queries) -> None: ...
    @property
    def colors(self): ...
    @colors.setter
    def colors(self, colors) -> None: ...
    @property
    def shape(self): ...
    @shape.setter
    def shape(self, shape) -> None: ...
    @property
    def note(self): ...
    @note.setter
    def note(self, note) -> None: ...
    @property
    def show_note_when_empty(self): ...
    @show_note_when_empty.setter
    def show_note_when_empty(self, show_note_when_empty) -> None: ...
    @property
    def table_options(self): ...
    @table_options.setter
    def table_options(self, table_options) -> None: ...
    @property
    def field_options(self): ...
    @field_options.setter
    def field_options(self, field_options) -> None: ...
    @property
    def time_format(self): ...
    @time_format.setter
    def time_format(self, time_format) -> None: ...
    @property
    def decimal_places(self): ...
    @decimal_places.setter
    def decimal_places(self, decimal_places) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
