from _cffi_backend import _CDataBase

class Refspec:
    def __init__(self, owner: _CDataBase, ptr: _CDataBase) -> None: ...
    @property
    def src(self) -> str: ...
    @property
    def dst(self) -> str: ...
    @property
    def force(self) -> bool: ...
    @property
    def string(self) -> str: ...
    @property
    def direction(self) -> int: ...
    def src_matches(self, ref: str) -> bool: ...
    def dst_matches(self, ref: str) -> bool: ...
    def transform(self, ref: str) -> str: ...
    def rtransform(self, ref: str) -> str: ...
