from _typeshed import Incomplete
from collections.abc import Generator

def cuthill_mckee_ordering(G, heuristic: Incomplete | None = None) -> Generator[Incomplete, Incomplete, None]: ...
def reverse_cuthill_mckee_ordering(G, heuristic: Incomplete | None = None): ...
