from collections.abc import Sequence

def namedtuple(typename: str, field_names: Sequence[str], verbose: bool = False, rename: bool = False): ...
def namedlist(typename: str, field_names: Sequence[str], verbose: bool = False, rename: bool = False): ...
