from _typeshed import Incomplete

class CustomerGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def all(self): ...
    def create(self, params: Incomplete | None = None): ...
    def delete(self, customer_id): ...
    def find(self, customer_id, association_filter_id: Incomplete | None = None): ...
    def search(self, *query): ...
    def update(self, customer_id, params: Incomplete | None = None): ...
