from influxdb_client import Organization

class OrganizationsApi:
    def __init__(self, influxdb_client) -> None: ...
    def me(self): ...
    def find_organization(self, org_id): ...
    def find_organizations(self, **kwargs): ...
    def create_organization(self, name: str | None = None, organization: Organization | None = None) -> Organization: ...
    def update_organization(self, organization: Organization) -> Organization: ...
    def delete_organization(self, org_id: str): ...
