from _typeshed import Incomplete
from collections.abc import Generator

class ResourceCollection:
    def __init__(self, query, results, method) -> None: ...
    @property
    def maximum_size(self): ...
    @property
    def first(self): ...
    @property
    def items(self) -> Generator[Incomplete, None, None]: ...
    @property
    def ids(self): ...
    def __iter__(self): ...
