from _typeshed import Incomplete

class Links:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, next: Incomplete | None = None, _self: Incomplete | None = None, prev: Incomplete | None = None
    ) -> None: ...
    @property
    def next(self): ...
    @next.setter
    def next(self, next) -> None: ...
    @property
    def prev(self): ...
    @prev.setter
    def prev(self, prev) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
