from collections.abc import Iterable

DEFAULT_MOUNT_POINT: str
ALLOWED_CREDS_ENDPOINTS: Iterable[str]
ALLOWED_CREDS_TYPES: Iterable[str]
ALLOWED_IAM_ALIAS_TYPES: Iterable[str]
ALLOWED_EC2_ALIAS_TYPES: Iterable[str]
