from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class BackupService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_backup_kv(self, **kwargs): ...
    def get_backup_kv_with_http_info(self, **kwargs): ...
    async def get_backup_kv_async(self, **kwargs): ...
    def get_backup_metadata(self, **kwargs): ...
    def get_backup_metadata_with_http_info(self, **kwargs): ...
    async def get_backup_metadata_async(self, **kwargs): ...
    def get_backup_shard_id(self, shard_id, **kwargs): ...
    def get_backup_shard_id_with_http_info(self, shard_id, **kwargs): ...
    async def get_backup_shard_id_async(self, shard_id, **kwargs): ...
