from typing import Final

Approve: Final = "approve_me"
InsufficientFundsContactUs: Final = "insufficient_funds__contact"
AccountNotAuthorizedContactUs: Final = "account_not_authorized__contact"
BankRejectedUpdateFundingInformation: Final = "bank_rejected__update"
BankRejectedNone: Final = "bank_rejected__none"
