from collections.abc import Generator
from typing import Any

WHEEL_NAME: Any
NAMESPACE_PACKAGE_INIT: str

def unpack(src_dir, dst_dir) -> None: ...
def disable_info_traces() -> Generator[None, None, None]: ...

class Wheel:
    filename: Any
    def __init__(self, filename) -> None: ...
    def tags(self): ...
    def is_compatible(self): ...
    def egg_name(self): ...
    def get_dist_info(self, zf): ...
    def install_as_egg(self, destination_eggdir) -> None: ...
