from networkx.utils.backends import _dispatch

@_dispatch
def maximal_matching(G): ...
@_dispatch
def is_matching(G, matching): ...
@_dispatch
def is_maximal_matching(G, matching): ...
@_dispatch
def is_perfect_matching(G, matching): ...
@_dispatch
def min_weight_matching(G, weight: str = "weight"): ...
@_dispatch
def max_weight_matching(G, maxcardinality: bool = False, weight: str = "weight"): ...
