from typing import Any

CS_ESCAPE: Any
FIRST_ELEMENT: Any

def make_charset(letters): ...
def regex_opt_inner(strings, open_paren): ...
def regex_opt(strings, prefix: str = "", suffix: str = ""): ...
