from _typeshed import Incomplete

class ValidationErrorCollection:
    data: dict[str, Incomplete]
    def __init__(self, data: Incomplete | None = None) -> None: ...
    @property
    def deep_errors(self): ...
    def for_index(self, index): ...
    def for_object(self, nested_key): ...
    def on(self, attribute): ...
    @property
    def deep_size(self): ...
    @property
    def errors(self): ...
    @property
    def size(self): ...
    def __getitem__(self, index): ...
    def __len__(self) -> int: ...
