from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def margulis_gabber_galil_graph(n, create_using: Incomplete | None = None): ...
@_dispatch
def chordal_cycle_graph(p, create_using: Incomplete | None = None): ...
@_dispatch
def paley_graph(p, create_using: Incomplete | None = None): ...
