from collections.abc import Iterable

DEFAULT_MOUNT_POINT: str
ALLOWED_ROLE_TYPES: Iterable[str]
ALLOWED_SECRETS_TYPES: Iterable[str]
SERVICE_ACCOUNT_KEY_ALGORITHMS: Iterable[str]
SERVICE_ACCOUNT_KEY_TYPES: Iterable[str]
GCP_CERTS_ENDPOINT: str
