from networkx.utils.backends import _dispatch

@_dispatch
def karate_club_graph(): ...
@_dispatch
def davis_southern_women_graph(): ...
@_dispatch
def florentine_families_graph(): ...
@_dispatch
def les_miserables_graph(): ...
