from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def closeness_vitality(
    G, node: Incomplete | None = None, weight: Incomplete | None = None, wiener_index: Incomplete | None = None
): ...
