from _typeshed import Incomplete

class MeasurementSchemaList:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, measurement_schemas: Incomplete | None = None) -> None: ...
    @property
    def measurement_schemas(self): ...
    @measurement_schemas.setter
    def measurement_schemas(self, measurement_schemas) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
