from markdown.core import Markdown

from . import util

def build_postprocessors(md: Markdown, **kwargs) -> util.Registry[Postprocessor]: ...

class Postprocessor(util.Processor):
    def run(self, text: str) -> str: ...

class RawHtmlPostprocessor(Postprocessor):
    def isblocklevel(self, html: str) -> bool: ...
    def stash_to_string(self, text: str) -> str: ...

class AndSubstitutePostprocessor(Postprocessor): ...
