from typing import Final

XK_space: Final = 0x020
XK_exclam: Final = 0x021
XK_quotedbl: Final = 0x022
XK_numbersign: Final = 0x023
XK_dollar: Final = 0x024
XK_percent: Final = 0x025
XK_ampersand: Final = 0x026
XK_apostrophe: Final = 0x027
XK_quoteright: Final = 0x027
XK_parenleft: Final = 0x028
XK_parenright: Final = 0x029
XK_asterisk: Final = 0x02A
XK_plus: Final = 0x02B
XK_comma: Final = 0x02C
XK_minus: Final = 0x02D
XK_period: Final = 0x02E
XK_slash: Final = 0x02F
XK_0: Final = 0x030
XK_1: Final = 0x031
XK_2: Final = 0x032
XK_3: Final = 0x033
XK_4: Final = 0x034
XK_5: Final = 0x035
XK_6: Final = 0x036
XK_7: Final = 0x037
XK_8: Final = 0x038
XK_9: Final = 0x039
XK_colon: Final = 0x03A
XK_semicolon: Final = 0x03B
XK_less: Final = 0x03C
XK_equal: Final = 0x03D
XK_greater: Final = 0x03E
XK_question: Final = 0x03F
XK_at: Final = 0x040
XK_A: Final = 0x041
XK_B: Final = 0x042
XK_C: Final = 0x043
XK_D: Final = 0x044
XK_E: Final = 0x045
XK_F: Final = 0x046
XK_G: Final = 0x047
XK_H: Final = 0x048
XK_I: Final = 0x049
XK_J: Final = 0x04A
XK_K: Final = 0x04B
XK_L: Final = 0x04C
XK_M: Final = 0x04D
XK_N: Final = 0x04E
XK_O: Final = 0x04F
XK_P: Final = 0x050
XK_Q: Final = 0x051
XK_R: Final = 0x052
XK_S: Final = 0x053
XK_T: Final = 0x054
XK_U: Final = 0x055
XK_V: Final = 0x056
XK_W: Final = 0x057
XK_X: Final = 0x058
XK_Y: Final = 0x059
XK_Z: Final = 0x05A
XK_bracketleft: Final = 0x05B
XK_backslash: Final = 0x05C
XK_bracketright: Final = 0x05D
XK_asciicircum: Final = 0x05E
XK_underscore: Final = 0x05F
XK_grave: Final = 0x060
XK_quoteleft: Final = 0x060
XK_a: Final = 0x061
XK_b: Final = 0x062
XK_c: Final = 0x063
XK_d: Final = 0x064
XK_e: Final = 0x065
XK_f: Final = 0x066
XK_g: Final = 0x067
XK_h: Final = 0x068
XK_i: Final = 0x069
XK_j: Final = 0x06A
XK_k: Final = 0x06B
XK_l: Final = 0x06C
XK_m: Final = 0x06D
XK_n: Final = 0x06E
XK_o: Final = 0x06F
XK_p: Final = 0x070
XK_q: Final = 0x071
XK_r: Final = 0x072
XK_s: Final = 0x073
XK_t: Final = 0x074
XK_u: Final = 0x075
XK_v: Final = 0x076
XK_w: Final = 0x077
XK_x: Final = 0x078
XK_y: Final = 0x079
XK_z: Final = 0x07A
XK_braceleft: Final = 0x07B
XK_bar: Final = 0x07C
XK_braceright: Final = 0x07D
XK_asciitilde: Final = 0x07E
XK_nobreakspace: Final = 0x0A0
XK_exclamdown: Final = 0x0A1
XK_cent: Final = 0x0A2
XK_sterling: Final = 0x0A3
XK_currency: Final = 0x0A4
XK_yen: Final = 0x0A5
XK_brokenbar: Final = 0x0A6
XK_section: Final = 0x0A7
XK_diaeresis: Final = 0x0A8
XK_copyright: Final = 0x0A9
XK_ordfeminine: Final = 0x0AA
XK_guillemotleft: Final = 0x0AB
XK_notsign: Final = 0x0AC
XK_hyphen: Final = 0x0AD
XK_registered: Final = 0x0AE
XK_macron: Final = 0x0AF
XK_degree: Final = 0x0B0
XK_plusminus: Final = 0x0B1
XK_twosuperior: Final = 0x0B2
XK_threesuperior: Final = 0x0B3
XK_acute: Final = 0x0B4
XK_mu: Final = 0x0B5
XK_paragraph: Final = 0x0B6
XK_periodcentered: Final = 0x0B7
XK_cedilla: Final = 0x0B8
XK_onesuperior: Final = 0x0B9
XK_masculine: Final = 0x0BA
XK_guillemotright: Final = 0x0BB
XK_onequarter: Final = 0x0BC
XK_onehalf: Final = 0x0BD
XK_threequarters: Final = 0x0BE
XK_questiondown: Final = 0x0BF
XK_Agrave: Final = 0x0C0
XK_Aacute: Final = 0x0C1
XK_Acircumflex: Final = 0x0C2
XK_Atilde: Final = 0x0C3
XK_Adiaeresis: Final = 0x0C4
XK_Aring: Final = 0x0C5
XK_AE: Final = 0x0C6
XK_Ccedilla: Final = 0x0C7
XK_Egrave: Final = 0x0C8
XK_Eacute: Final = 0x0C9
XK_Ecircumflex: Final = 0x0CA
XK_Ediaeresis: Final = 0x0CB
XK_Igrave: Final = 0x0CC
XK_Iacute: Final = 0x0CD
XK_Icircumflex: Final = 0x0CE
XK_Idiaeresis: Final = 0x0CF
XK_ETH: Final = 0x0D0
XK_Eth: Final = 0x0D0
XK_Ntilde: Final = 0x0D1
XK_Ograve: Final = 0x0D2
XK_Oacute: Final = 0x0D3
XK_Ocircumflex: Final = 0x0D4
XK_Otilde: Final = 0x0D5
XK_Odiaeresis: Final = 0x0D6
XK_multiply: Final = 0x0D7
XK_Ooblique: Final = 0x0D8
XK_Ugrave: Final = 0x0D9
XK_Uacute: Final = 0x0DA
XK_Ucircumflex: Final = 0x0DB
XK_Udiaeresis: Final = 0x0DC
XK_Yacute: Final = 0x0DD
XK_THORN: Final = 0x0DE
XK_Thorn: Final = 0x0DE
XK_ssharp: Final = 0x0DF
XK_agrave: Final = 0x0E0
XK_aacute: Final = 0x0E1
XK_acircumflex: Final = 0x0E2
XK_atilde: Final = 0x0E3
XK_adiaeresis: Final = 0x0E4
XK_aring: Final = 0x0E5
XK_ae: Final = 0x0E6
XK_ccedilla: Final = 0x0E7
XK_egrave: Final = 0x0E8
XK_eacute: Final = 0x0E9
XK_ecircumflex: Final = 0x0EA
XK_ediaeresis: Final = 0x0EB
XK_igrave: Final = 0x0EC
XK_iacute: Final = 0x0ED
XK_icircumflex: Final = 0x0EE
XK_idiaeresis: Final = 0x0EF
XK_eth: Final = 0x0F0
XK_ntilde: Final = 0x0F1
XK_ograve: Final = 0x0F2
XK_oacute: Final = 0x0F3
XK_ocircumflex: Final = 0x0F4
XK_otilde: Final = 0x0F5
XK_odiaeresis: Final = 0x0F6
XK_division: Final = 0x0F7
XK_oslash: Final = 0x0F8
XK_ugrave: Final = 0x0F9
XK_uacute: Final = 0x0FA
XK_ucircumflex: Final = 0x0FB
XK_udiaeresis: Final = 0x0FC
XK_yacute: Final = 0x0FD
XK_thorn: Final = 0x0FE
XK_ydiaeresis: Final = 0x0FF
