from hvac.utils import _DeprecateProperty

DEPRECATED_PROPERTIES: dict[str, _DeprecateProperty]
DEFAULT_URL: str
VAULT_CACERT: str | None
VAULT_CAPATH: str | None
VAULT_CLIENT_CERT: str | None
VAULT_CLIENT_KEY: str | None
