from _typeshed import Incomplete

class PayPalAccountGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def find(self, paypal_account_token): ...
    def delete(self, paypal_account_token): ...
    def update(self, paypal_account_token, params: Incomplete | None = None): ...
